@@ -20,38 +20,39 @@ See the License for the specific language governing permissions and
 limitations under the License.
 */
 
-package common
+package cli
 
 import (
-	"io/ioutil"
+	"io"
 	"testing"
 
 	"github.com/stretchr/testify/assert"
 
-	. "github.com/apache/camel-k/e2e/support"
+	. "github.com/apache/camel-k/v2/e2e/support"
+	. "github.com/onsi/gomega"
 )
 
 func TestKamelVersionWorksOffline(t *testing.T) {
+	RegisterTestingT(t)
+
 	assert.Nil(t, Kamel("version", "--kube-config", "non-existent-kubeconfig-file").Execute())
 }
 
-func TestKamelHelpTraitWorksOffline(t *testing.T) {
-	traitCmd := Kamel("help", "trait", "--all", "--kube-config", "non-existent-kubeconfig-file")
-	traitCmd.SetOut(ioutil.Discard)
-	assert.Nil(t, traitCmd.Execute())
-}
-
 func TestKamelHelpOptionWorksOffline(t *testing.T) {
+	RegisterTestingT(t)
+
 	traitCmd := Kamel("run", "Xxx.java", "--help")
-	traitCmd.SetOut(ioutil.Discard)
+	traitCmd.SetOut(io.Discard)
 	assert.Nil(t, traitCmd.Execute())
 }
 
 func TestKamelCompletionWorksOffline(t *testing.T) {
+	RegisterTestingT(t)
+
 	bashCmd := Kamel("completion", "bash", "--kube-config", "non-existent-kubeconfig-file")
-	bashCmd.SetOut(ioutil.Discard)
+	bashCmd.SetOut(io.Discard)
 	zshCmd := Kamel("completion", "zsh", "--kube-config", "non-existent-kubeconfig-file")
-	zshCmd.SetOut(ioutil.Discard)
+	zshCmd.SetOut(io.Discard)
 	assert.Nil(t, bashCmd.Execute())
 	assert.Nil(t, zshCmd.Execute())
 }
