@@ -1,3 +1,4 @@
+//go:build integration
 // +build integration
 
 // To enable compilation of this file in Goland, go to "Settings -> Go -> Vendoring & Build Tags -> Custom Tags" and add "integration"
@@ -19,22 +20,22 @@ See the License for the specific language governing permissions and
 limitations under the License.
 */
 
-package common
+package cli
 
 import (
-	"github.com/apache/camel-k/pkg/util/defaults"
 	"testing"
 
 	. "github.com/onsi/gomega"
 
-	. "github.com/apache/camel-k/e2e/support"
+	. "github.com/apache/camel-k/v2/e2e/support"
+	"github.com/apache/camel-k/v2/pkg/util/defaults"
 )
 
 func TestKamelCLIVersion(t *testing.T) {
-	WithNewTestNamespace(t, func(ns string) {
-		t.Run("check version correctness", func(t *testing.T) {
-			version := GetOutputString(Kamel("version"))
-			Expect(version).To(ContainSubstring(defaults.Version))
-		})
+	RegisterTestingT(t)
+
+	t.Run("check version correctness", func(t *testing.T) {
+		version := GetOutputString(Kamel("version"))
+		Expect(version).To(ContainSubstring(defaults.Version))
 	})
 }
