@@ -27,9 +27,9 @@ import (
 	"bytes"
 	"context"
 	"encoding/json"
+	"errors"
 	"fmt"
 	"io"
-	"io/ioutil"
 	"os"
 	"os/exec"
 	"reflect"
@@ -45,7 +45,7 @@ import (
 	"github.com/google/uuid"
 	"github.com/onsi/gomega"
 	"github.com/onsi/gomega/format"
-	"github.com/pkg/errors"
+
 	"github.com/spf13/cobra"
 	appsv1 "k8s.io/api/apps/v1"
 	batchv1 "k8s.io/api/batch/v1"
@@ -71,25 +71,26 @@ import (
 	projectv1 "github.com/openshift/api/project/v1"
 	routev1 "github.com/openshift/api/route/v1"
 
-	"github.com/apache/camel-k/e2e/support/util"
-	v1 "github.com/apache/camel-k/pkg/apis/camel/v1"
-	traitv1 "github.com/apache/camel-k/pkg/apis/camel/v1/trait"
-	"github.com/apache/camel-k/pkg/apis/camel/v1alpha1"
-	"github.com/apache/camel-k/pkg/client"
-	"github.com/apache/camel-k/pkg/cmd"
-	"github.com/apache/camel-k/pkg/install"
-	"github.com/apache/camel-k/pkg/platform"
-	"github.com/apache/camel-k/pkg/util/defaults"
-	"github.com/apache/camel-k/pkg/util/kubernetes"
-	"github.com/apache/camel-k/pkg/util/log"
-	"github.com/apache/camel-k/pkg/util/openshift"
-	"github.com/apache/camel-k/pkg/util/patch"
+	"github.com/apache/camel-k/v2/e2e/support/util"
+	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
+	traitv1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1/trait"
+	v1alpha1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1alpha1"
+	"github.com/apache/camel-k/v2/pkg/client"
+	"github.com/apache/camel-k/v2/pkg/cmd"
+	"github.com/apache/camel-k/v2/pkg/install"
+	"github.com/apache/camel-k/v2/pkg/platform"
+	"github.com/apache/camel-k/v2/pkg/util/defaults"
+	"github.com/apache/camel-k/v2/pkg/util/kubernetes"
+	"github.com/apache/camel-k/v2/pkg/util/log"
+	"github.com/apache/camel-k/v2/pkg/util/openshift"
+	"github.com/apache/camel-k/v2/pkg/util/patch"
 
 	// let's enable addons in all tests
-	_ "github.com/apache/camel-k/addons"
+	_ "github.com/apache/camel-k/v2/addons"
 )
 
 const kubeConfigEnvVar = "KUBECONFIG"
+const ciPID = "/tmp/ci-k8s-pid"
 
 var TestTimeoutShort = 1 * time.Minute
 var TestTimeoutMedium = 5 * time.Minute
@@ -279,6 +280,17 @@ func kamelInstallWithContext(ctx context.Context, operatorID string, namespace s
 		}
 	}
 
+	opImage := os.Getenv("CAMEL_K_TEST_OPERATOR_IMAGE")
+	if opImage != "" {
+		fmt.Printf("Setting operator image to %s\n", opImage)
+		installArgs = append(installArgs, "--operator-image", opImage)
+	}
+	opImagePullPolicy := os.Getenv("CAMEL_K_TEST_OPERATOR_IMAGE_PULL_POLICY")
+	if opImagePullPolicy != "" {
+		fmt.Printf("Setting operator image pull policy to %s\n", opImagePullPolicy)
+		installArgs = append(installArgs, "--operator-image-pull-policy", opImagePullPolicy)
+	}
+
 	installArgs = append(installArgs, args...)
 	return KamelWithContext(ctx, installArgs...)
 }
@@ -337,7 +349,7 @@ func verifyGlobalOperator() error {
 
 	oppod := OperatorPod(opns)()
 	if oppod == nil {
-		return fmt.Errorf("No operator pod detected in namespace %s. Operator install is a pre-requisite of the test", opns)
+		return fmt.Errorf("no operator pod detected in namespace %s. Operator install is a pre-requisite of the test", opns)
 	}
 
 	return nil
@@ -367,11 +379,15 @@ func KamelWithContext(ctx context.Context, args ...string) *cobra.Command {
 			DisableFlagParsing: true,
 			RunE: func(cmd *cobra.Command, args []string) error {
 				externalBin := exec.CommandContext(ctx, kamelBin, args...)
-				var stdout io.Reader
+				var stdout, stderr io.Reader
 				stdout, err = externalBin.StdoutPipe()
 				if err != nil {
 					failTest(err)
 				}
+				stderr, err = externalBin.StderrPipe()
+				if err != nil {
+					failTest(err)
+				}
 				err := externalBin.Start()
 				if err != nil {
 					return err
@@ -380,6 +396,10 @@ func KamelWithContext(ctx context.Context, args ...string) *cobra.Command {
 				if err != nil {
 					return err
 				}
+				_, err = io.Copy(c.ErrOrStderr(), stderr)
+				if err != nil {
+					return err
+				}
 				err = externalBin.Wait()
 				if err != nil {
 					return err
@@ -476,7 +496,7 @@ func Logs(ns, podName string, options corev1.PodLogOptions) func() string {
 			}
 		}()
 
-		bytes, err := ioutil.ReadAll(byteReader)
+		bytes, err := io.ReadAll(byteReader)
 		if err != nil {
 			log.Error(err, "Error while reading container logs")
 			return ""
@@ -1015,6 +1035,16 @@ func KitPhase(ns, name string) func() v1.IntegrationKitPhase {
 	}
 }
 
+func KitCondition(ns string, name string, conditionType v1.IntegrationKitConditionType) func() *v1.IntegrationKitCondition {
+	return func() *v1.IntegrationKitCondition {
+		kt := Kit(ns, name)()
+		if kt == nil {
+			return nil
+		}
+		return kt.Status.GetCondition(conditionType)
+	}
+}
+
 func UpdateIntegration(ns string, name string, mutate func(it *v1.Integration)) error {
 	it := Integration(ns, name)()
 	if it == nil {
@@ -1047,9 +1077,9 @@ func ScaleIntegration(ns string, name string, replicas int32) error {
 	})
 }
 
-func KameletBinding(ns string, name string) func() *v1alpha1.KameletBinding {
-	return func() *v1alpha1.KameletBinding {
-		klb := v1alpha1.NewKameletBinding(ns, name)
+func Pipe(ns string, name string) func() *v1.Pipe {
+	return func() *v1.Pipe {
+		klb := v1.NewPipe(ns, name)
 		key := ctrl.ObjectKey{
 			Namespace: ns,
 			Name:      name,
@@ -1063,9 +1093,9 @@ func KameletBinding(ns string, name string) func() *v1alpha1.KameletBinding {
 	}
 }
 
-func KameletBindingPhase(ns string, name string) func() v1alpha1.KameletBindingPhase {
-	return func() v1alpha1.KameletBindingPhase {
-		klb := KameletBinding(ns, name)()
+func PipePhase(ns string, name string) func() v1.PipePhase {
+	return func() v1.PipePhase {
+		klb := Pipe(ns, name)()
 		if klb == nil {
 			return ""
 		}
@@ -1073,9 +1103,9 @@ func KameletBindingPhase(ns string, name string) func() v1alpha1.KameletBindingP
 	}
 }
 
-func KameletBindingSpecReplicas(ns string, name string) func() *int32 {
+func PipeSpecReplicas(ns string, name string) func() *int32 {
 	return func() *int32 {
-		klb := KameletBinding(ns, name)()
+		klb := Pipe(ns, name)()
 		if klb == nil {
 			return nil
 		}
@@ -1083,9 +1113,9 @@ func KameletBindingSpecReplicas(ns string, name string) func() *int32 {
 	}
 }
 
-func KameletBindingStatusReplicas(ns string, name string) func() *int32 {
+func PipeStatusReplicas(ns string, name string) func() *int32 {
 	return func() *int32 {
-		klb := KameletBinding(ns, name)()
+		klb := Pipe(ns, name)()
 		if klb == nil {
 			return nil
 		}
@@ -1093,9 +1123,9 @@ func KameletBindingStatusReplicas(ns string, name string) func() *int32 {
 	}
 }
 
-func KameletBindingCondition(ns string, name string, conditionType v1alpha1.KameletBindingConditionType) func() *v1alpha1.KameletBindingCondition {
-	return func() *v1alpha1.KameletBindingCondition {
-		kb := KameletBinding(ns, name)()
+func PipeCondition(ns string, name string, conditionType v1.PipeConditionType) func() *v1.PipeCondition {
+	return func() *v1.PipeCondition {
+		kb := Pipe(ns, name)()
 		if kb == nil {
 			return nil
 		}
@@ -1107,32 +1137,32 @@ func KameletBindingCondition(ns string, name string, conditionType v1alpha1.Kame
 	}
 }
 
-func KameletBindingConditionStatusExtract(c *v1alpha1.KameletBindingCondition) corev1.ConditionStatus {
+func PipeConditionStatusExtract(c *v1.PipeCondition) corev1.ConditionStatus {
 	if c == nil {
 		return ""
 	}
 	return c.Status
 }
 
-func KameletBindingConditionReason(c *v1alpha1.KameletBindingCondition) string {
+func PipeConditionReason(c *v1.PipeCondition) string {
 	if c == nil {
 		return ""
 	}
 	return c.Reason
 }
 
-func KameletBindingConditionMessage(c *v1alpha1.KameletBindingCondition) string {
+func PipeConditionMessage(c *v1.PipeCondition) string {
 	if c == nil {
 		return ""
 	}
 	return c.Message
 }
 
-func KameletBindingConditionStatus(ns string, name string, conditionType v1alpha1.KameletBindingConditionType) func() corev1.ConditionStatus {
+func PipeConditionStatus(ns string, name string, conditionType v1.PipeConditionType) func() corev1.ConditionStatus {
 	return func() corev1.ConditionStatus {
-		klb := KameletBinding(ns, name)()
+		klb := Pipe(ns, name)()
 		if klb == nil {
-			return "KameletBindingMissing"
+			return "PipeMissing"
 		}
 		c := klb.Status.GetCondition(conditionType)
 		if c == nil {
@@ -1142,10 +1172,10 @@ func KameletBindingConditionStatus(ns string, name string, conditionType v1alpha
 	}
 }
 
-func UpdateKameletBinding(ns string, name string, upd func(it *v1alpha1.KameletBinding)) error {
-	klb := KameletBinding(ns, name)()
+func UpdatePipe(ns string, name string, upd func(it *v1.Pipe)) error {
+	klb := Pipe(ns, name)()
 	if klb == nil {
-		return fmt.Errorf("no kamelet binding named %s found", name)
+		return fmt.Errorf("no Pipe named %s found", name)
 	}
 	target := klb.DeepCopy()
 	upd(target)
@@ -1159,16 +1189,16 @@ func UpdateKameletBinding(ns string, name string, upd func(it *v1alpha1.KameletB
 	return TestClient().Patch(TestContext, target, ctrl.RawPatch(types.MergePatchType, p))
 }
 
-func ScaleKameletBinding(ns string, name string, replicas int32) error {
-	return UpdateKameletBinding(ns, name, func(klb *v1alpha1.KameletBinding) {
+func ScalePipe(ns string, name string, replicas int32) error {
+	return UpdatePipe(ns, name, func(klb *v1.Pipe) {
 		klb.Spec.Replicas = &replicas
 	})
 }
 
-func AssignKameletBindingToOperator(ns, name, operator string) error {
-	klb := KameletBinding(ns, name)()
+func AssignPipeToOperator(ns, name, operator string) error {
+	klb := Pipe(ns, name)()
 	if klb == nil {
-		return fmt.Errorf("cannot assign kamelet binding %q to operator: kamelet binding not found", name)
+		return fmt.Errorf("cannot assign Pipe %q to operator:Pipe not found", name)
 	}
 
 	klb.SetOperatorID(operator)
@@ -1338,6 +1368,61 @@ func Configmap(ns string, name string) func() *corev1.ConfigMap {
 	}
 }
 
+func BuilderPod(ns string, name string) func() *corev1.Pod {
+	return func() *corev1.Pod {
+		pod := corev1.Pod{
+			TypeMeta: metav1.TypeMeta{
+				Kind:       "Pod",
+				APIVersion: corev1.SchemeGroupVersion.String(),
+			},
+			ObjectMeta: metav1.ObjectMeta{
+				Namespace: ns,
+				Name:      name,
+			},
+		}
+		key := ctrl.ObjectKey{
+			Namespace: ns,
+			Name:      name,
+		}
+		if err := TestClient().Get(TestContext, key, &pod); err != nil && k8serrors.IsNotFound(err) {
+			return nil
+		} else if err != nil {
+			log.Error(err, "Error while retrieving pod "+name)
+			return nil
+		}
+		return &pod
+	}
+}
+
+func BuilderPodPhase(ns string, name string) func() corev1.PodPhase {
+	return func() corev1.PodPhase {
+		pod := BuilderPod(ns, name)()
+		if pod == nil {
+			return ""
+		}
+		return pod.Status.Phase
+	}
+}
+
+func BuilderPodsCount(ns string) func() int {
+	return func() int {
+		lst := corev1.PodList{
+			TypeMeta: metav1.TypeMeta{
+				Kind:       "Pod",
+				APIVersion: corev1.SchemeGroupVersion.String(),
+			},
+		}
+		if err := TestClient().List(TestContext, &lst,
+			ctrl.InNamespace(ns),
+			ctrl.MatchingLabels{
+				"camel.apache.org/component": "builder",
+			}); err != nil {
+			failTest(err)
+		}
+		return len(lst.Items)
+	}
+}
+
 func AutogeneratedConfigmapsCount(ns string) func() int {
 	return func() int {
 		lst := corev1.ConfigMapList{
@@ -1466,6 +1551,26 @@ func KnativeService(ns string, name string) func() *servingv1.Service {
 		return &answer
 	}
 }
+func DeploymentWithIntegrationLabel(ns string, label string) func() *appsv1.Deployment {
+	return func() *appsv1.Deployment {
+		lst := appsv1.DeploymentList{
+			TypeMeta: metav1.TypeMeta{
+				Kind:       "Deployment",
+				APIVersion: appsv1.SchemeGroupVersion.String(),
+			},
+		}
+		if err := TestClient().List(TestContext, &lst, ctrl.InNamespace(ns), ctrl.MatchingLabels{v1.IntegrationLabel: label}); err != nil && k8serrors.IsNotFound(err) {
+			return nil
+		} else if err != nil {
+			log.Errorf(err, "Error while retrieving deployment %s", label)
+			return nil
+		}
+		if len(lst.Items) == 0 {
+			return nil
+		}
+		return &lst.Items[0]
+	}
+}
 
 func Deployment(ns string, name string) func() *appsv1.Deployment {
 	return func() *appsv1.Deployment {
@@ -1525,6 +1630,16 @@ func Build(ns, name string) func() *v1.Build {
 	}
 }
 
+func BuildConfig(ns, name string) func() v1.BuildConfiguration {
+	return func() v1.BuildConfiguration {
+		build := Build(ns, name)()
+		if build != nil {
+			return *build.BuilderConfiguration()
+		}
+		return v1.BuildConfiguration{}
+	}
+}
+
 func BuildPhase(ns, name string) func() v1.BuildPhase {
 	return func() v1.BuildPhase {
 		build := Build(ns, name)()
@@ -1535,6 +1650,26 @@ func BuildPhase(ns, name string) func() v1.BuildPhase {
 	}
 }
 
+func BuildConditions(ns, name string) func() []v1.BuildCondition {
+	return func() []v1.BuildCondition {
+		build := Build(ns, name)()
+		if build != nil && &build.Status != nil && build.Status.Conditions != nil {
+			return build.Status.Conditions
+		}
+		return nil
+	}
+}
+
+func BuildFailureRecovery(ns, name string) func() int {
+	return func() int {
+		build := Build(ns, name)()
+		if build != nil {
+			return build.Status.Failure.Recovery.Attempt
+		}
+		return 0
+	}
+}
+
 func BuildsRunning(predicates ...func() v1.BuildPhase) func() int {
 	return func() int {
 		runningBuilds := 0
@@ -1587,6 +1722,112 @@ func Platform(ns string) func() *v1.IntegrationPlatform {
 	}
 }
 
+func PlatformByName(ns string, name string) func() *v1.IntegrationPlatform {
+	return func() *v1.IntegrationPlatform {
+		lst := v1.NewIntegrationPlatformList()
+		if err := TestClient().List(TestContext, &lst, ctrl.InNamespace(ns)); err != nil {
+			failTest(err)
+		}
+		for _, p := range lst.Items {
+			if p.Name == name {
+				return &p
+			}
+		}
+		return nil
+	}
+}
+
+func CamelCatalog(ns, name string) func() *v1.CamelCatalog {
+	return func() *v1.CamelCatalog {
+		cat := v1.CamelCatalog{}
+		key := ctrl.ObjectKey{
+			Namespace: ns,
+			Name:      name,
+		}
+		if err := TestClient().Get(TestContext, key, &cat); err != nil && !k8serrors.IsNotFound(err) {
+			failTest(err)
+		} else if err != nil && k8serrors.IsNotFound(err) {
+			return nil
+		}
+		return &cat
+	}
+}
+
+func CreateCamelCatalog(catalog *v1.CamelCatalog) func() error {
+	return func() error {
+		return TestClient().Create(TestContext, catalog)
+	}
+}
+
+func DeleteCamelCatalog(ns, name string) func() bool {
+	return func() bool {
+		cat := CamelCatalog(ns, name)()
+		if cat == nil {
+			return true
+		}
+		if err := TestClient().Delete(TestContext, cat); err != nil {
+			log.Error(err, "Got error while deleting the catalog")
+		}
+		return true
+	}
+}
+
+func DefaultCamelCatalogPhase(ns string) func() v1.CamelCatalogPhase {
+	return func() v1.CamelCatalogPhase {
+		catalogName := fmt.Sprintf("camel-catalog-%s", strings.ToLower(defaults.DefaultRuntimeVersion))
+		c := CamelCatalog(ns, catalogName)()
+		if c == nil {
+			return ""
+		}
+		return c.Status.Phase
+	}
+}
+
+func CamelCatalogPhase(ns, name string) func() v1.CamelCatalogPhase {
+	return func() v1.CamelCatalogPhase {
+		c := CamelCatalog(ns, name)()
+		if c == nil {
+			return ""
+		}
+		return c.Status.Phase
+	}
+}
+
+func CamelCatalogCondition(ns, name string, conditionType v1.CamelCatalogConditionType) func() *v1.CamelCatalogCondition {
+	return func() *v1.CamelCatalogCondition {
+		c := CamelCatalog(ns, name)()
+		if c == nil {
+			return nil
+		}
+		for _, condition := range c.Status.Conditions {
+			if condition.Type == conditionType {
+				return &condition
+			}
+		}
+		return nil
+	}
+}
+
+func CamelCatalogImage(ns, name string) func() string {
+	return func() string {
+		c := CamelCatalog(ns, name)()
+		if c == nil {
+			return ""
+		}
+		return c.Status.Image
+	}
+}
+
+func CamelCatalogList(ns string) func() []v1.CamelCatalog {
+	return func() []v1.CamelCatalog {
+		lst := v1.NewCamelCatalogList()
+		if err := TestClient().List(TestContext, &lst, ctrl.InNamespace(ns)); err != nil {
+			failTest(err)
+		}
+		return lst.Items
+	}
+}
+
 func DeletePlatform(ns string) func() bool {
 	return func() bool {
 		pl := Platform(ns)()
@@ -1620,6 +1861,16 @@ func PlatformPhase(ns string) func() v1.IntegrationPlatformPhase {
 	}
 }
 
+func SelectedPlatformPhase(ns string, name string) func() v1.IntegrationPlatformPhase {
+	return func() v1.IntegrationPlatformPhase {
+		p := PlatformByName(ns, name)()
+		if p == nil {
+			return ""
+		}
+		return p.Status.Phase
+	}
+}
+
 func PlatformHas(ns string, predicate func(pl *v1.IntegrationPlatform) bool) func() bool {
 	return func() bool {
 		pl := Platform(ns)()
@@ -1666,6 +1917,26 @@ func PlatformProfile(ns string) func() v1.TraitProfile {
 	}
 }
 
+func PlatformBuildCatalogToolTimeout(ns string) func() *metav1.Duration {
+	return func() *metav1.Duration {
+		p := Platform(ns)()
+		if p == nil {
+			return &metav1.Duration{}
+		}
+		return p.Status.Build.BuildCatalogToolTimeout
+	}
+}
+
+func PlatformTimeout(ns string) func() *metav1.Duration {
+	return func() *metav1.Duration {
+		p := Platform(ns)()
+		if p == nil {
+			return &metav1.Duration{}
+		}
+		return p.Status.Build.Timeout
+	}
+}
+
 func AssignPlatformToOperator(ns, operator string) error {
 	pl := Platform(ns)()
 	if pl == nil {
@@ -1698,7 +1969,8 @@ func CRDs() func() []metav1.APIResource {
 			reflect.TypeOf(v1.Integration{}).Name(),
 			reflect.TypeOf(v1.IntegrationKit{}).Name(),
 			reflect.TypeOf(v1.IntegrationPlatform{}).Name(),
-			reflect.TypeOf(v1alpha1.Kamelet{}).Name(),
+			reflect.TypeOf(v1.Kamelet{}).Name(),
+			reflect.TypeOf(v1.Pipe{}).Name(),
 			reflect.TypeOf(v1alpha1.KameletBinding{}).Name(),
 		}
 
@@ -1910,9 +2182,9 @@ func ServiceAccount(ns, name string) func() *corev1.ServiceAccount {
 	}
 }
 
-func KameletList(ns string) func() []v1alpha1.Kamelet {
-	return func() []v1alpha1.Kamelet {
-		lst := v1alpha1.NewKameletList()
+func KameletList(ns string) func() []v1.Kamelet {
+	return func() []v1.Kamelet {
+		lst := v1.NewKameletList()
 		if err := TestClient().List(TestContext, &lst, ctrl.InNamespace(ns)); err != nil {
 			failTest(err)
 		}
@@ -1920,9 +2192,9 @@ func KameletList(ns string) func() []v1alpha1.Kamelet {
 	}
 }
 
-func Kamelet(name string, ns string) func() *v1alpha1.Kamelet {
-	return func() *v1alpha1.Kamelet {
-		it := v1alpha1.NewKamelet(ns, name)
+func Kamelet(name string, ns string) func() *v1.Kamelet {
+	return func() *v1.Kamelet {
+		it := v1.NewKamelet(ns, name)
 		key := ctrl.ObjectKey{
 			Namespace: ns,
 			Name:      name,
@@ -1936,7 +2208,7 @@ func Kamelet(name string, ns string) func() *v1alpha1.Kamelet {
 	}
 }
 
-func KameletLabels(kamelet *v1alpha1.Kamelet) map[string]string {
+func KameletLabels(kamelet *v1.Kamelet) map[string]string {
 	if kamelet == nil {
 		return map[string]string{}
 	}
@@ -2068,16 +2340,16 @@ func CreateKnativeBroker(ns string, name string) func() error {
 	Kamelets
 */
 
-func CreateKamelet(ns string, name string, template map[string]interface{}, properties map[string]v1alpha1.JSONSchemaProp, labels map[string]string) func() error {
+func CreateKamelet(ns string, name string, template map[string]interface{}, properties map[string]v1.JSONSchemaProp, labels map[string]string) func() error {
 	return func() error {
-		kamelet := v1alpha1.Kamelet{
+		kamelet := v1.Kamelet{
 			ObjectMeta: metav1.ObjectMeta{
 				Namespace: ns,
 				Name:      name,
 				Labels:    labels,
 			},
-			Spec: v1alpha1.KameletSpec{
-				Definition: &v1alpha1.JSONSchemaProps{
+			Spec: v1.KameletSpec{
+				Definition: &v1.JSONSchemaProps{
 					Properties: properties,
 				},
 				Template: asTemplate(template),
@@ -2088,7 +2360,7 @@ func CreateKamelet(ns string, name string, template map[string]interface{}, prop
 }
 
 func CreateTimerKamelet(ns string, name string) func() error {
-	props := map[string]v1alpha1.JSONSchemaProp{
+	props := map[string]v1.JSONSchemaProp{
 		"message": {
 			Type: "string",
 		},
@@ -2113,74 +2385,12 @@ func CreateTimerKamelet(ns string, name string) func() error {
 	return CreateKamelet(ns, name, flow, props, nil)
 }
 
-// Deprecated:
-// Use KamelBind func instead
-func BindKameletTo(ns, name string, annotations map[string]string, from, to corev1.ObjectReference,
-	sourceProperties, sinkProperties map[string]string) func() error {
-	return BindKameletToWithErrorHandler(ns, name, annotations, from, to, sourceProperties, sinkProperties, nil)
-}
-
-// Deprecated:
-// Use KamelBind func instead
-func BindKameletToWithErrorHandler(ns, name string, annotations map[string]string, from, to corev1.ObjectReference,
-	sourceProperties, sinkProperties map[string]string, errorHandler map[string]interface{}) func() error {
-	return func() error {
-		kb := v1alpha1.NewKameletBinding(ns, name)
-		kb.Annotations = annotations
-		kb.Spec = v1alpha1.KameletBindingSpec{
-			Source: v1alpha1.Endpoint{
-				Ref:        &from,
-				Properties: asEndpointProperties(sourceProperties),
-			},
-			Sink: v1alpha1.Endpoint{
-				Ref:        &to,
-				Properties: asEndpointProperties(sinkProperties),
-			},
-		}
-		if errorHandler != nil {
-			kb.Spec.ErrorHandler = asErrorHandlerSpec(errorHandler)
-		}
-		_, err := kubernetes.ReplaceResource(TestContext, TestClient(), &kb)
-		return err
-	}
-}
-
-// Deprecated:
-// Use KamelBind func instead
-func asTemplate(source map[string]interface{}) *v1alpha1.Template {
+func asTemplate(source map[string]interface{}) *v1.Template {
 	bytes, err := json.Marshal(source)
 	if err != nil {
 		failTest(err)
 	}
-	return &v1alpha1.Template{
-		RawMessage: bytes,
-	}
-}
-
-// Deprecated:
-// Use KamelBind func instead
-func asErrorHandlerSpec(source map[string]interface{}) *v1alpha1.ErrorHandlerSpec {
-	bytes, err := json.Marshal(source)
-	if err != nil {
-		failTest(err)
-	}
-	return &v1alpha1.ErrorHandlerSpec{
-		RawMessage: bytes,
-	}
-}
-
-// Deprecated:
-// Use KamelBind func instead
-func asEndpointProperties(props map[string]string) *v1alpha1.EndpointProperties {
-	if props == nil {
-		return &v1alpha1.EndpointProperties{}
-	}
-
-	bytes, err := json.Marshal(props)
-	if err != nil {
-		failTest(err)
-	}
-	return &v1alpha1.EndpointProperties{
+	return &v1.Template{
 		RawMessage: bytes,
 	}
 }
@@ -2521,7 +2731,7 @@ func CreateLogKamelet(ns string, name string) func() error {
 		},
 	}
 
-	props := map[string]v1alpha1.JSONSchemaProp{
+	props := map[string]v1.JSONSchemaProp{
 		"loggerName": {
 			Type: "string",
 		},
@@ -2529,3 +2739,34 @@ func CreateLogKamelet(ns string, name string) func() error {
 
 	return CreateKamelet(ns, name, flow, props, nil)
 }
+
+func GetCIProcessID() string {
+	id, err := os.ReadFile(ciPID)
+	if err != nil {
+		return ""
+	}
+	return string(id)
+}
+
+func SaveCIProcessID(id string) {
+	err := os.WriteFile(ciPID, []byte(id), 0644)
+	if err != nil {
+		panic(err)
+	}
+}
+
+func DeleteCIProcessID() {
+	err := os.Remove(ciPID)
+	if err != nil {
+		panic(err)
+	}
+}
+
+func GetOperatorNamespace(testNamespace string) string {
+	globalTest := os.Getenv("CAMEL_K_FORCE_GLOBAL_TEST") == "true"
+	if globalTest {
+		return os.Getenv("CAMEL_K_GLOBAL_OPERATOR_NS")
+	} else {
+		return testNamespace
+	}
+}
