@@ -21,7 +21,7 @@ import (
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 
-	"github.com/apache/camel-k/pkg/apis/camel/v1/trait"
+	"github.com/apache/camel-k/v2/pkg/apis/camel/v1/trait"
 )
 
 const (
@@ -35,19 +35,53 @@ const (
 	PlatformSelectorAnnotation = "camel.apache.org/platform.id"
 )
 
+// BuildConfiguration represent the configuration required to build the runtime
+type BuildConfiguration struct {
+	// The container image to be used to run the build.
+	ToolImage string `json:"toolImage,omitempty"`
+	// The namespace where to run the builder Pod (must be the same of the operator in charge of this Build reconciliation).
+	BuilderPodNamespace string `json:"operatorNamespace,omitempty"`
+	// the strategy to adopt
+	Strategy BuildStrategy `property:"strategy" json:"strategy,omitempty"`
+	// the build order strategy to adopt
+	OrderStrategy BuildOrderStrategy `property:"order-strategy" json:"orderStrategy,omitempty"`
+	// The minimum amount of CPU required. Only used for `pod` strategy
+	RequestCPU string `property:"request-cpu" json:"requestCPU,omitempty"`
+	// The minimum amount of memory required. Only used for `pod` strategy
+	RequestMemory string `property:"request-memory" json:"requestMemory,omitempty"`
+	// The maximum amount of CPU required. Only used for `pod` strategy
+	LimitCPU string `property:"limit-cpu" json:"limitCPU,omitempty"`
+	// The maximum amount of memory required. Only used for `pod` strategy
+	LimitMemory string `property:"limit-memory" json:"limitMemory,omitempty"`
+}
+
 // BuildStrategy specifies how the Build should be executed.
-// It will trigger a Maven process that will take care of producing the expected Camel/Camel-Quarkus runtime.
+// It will trigger a Maven process (either as an Operator routine or Kubernetes Pod execution) that
+// will take care of producing the expected Camel/Camel-Quarkus runtime.
 // +kubebuilder:validation:Enum=routine;pod
 type BuildStrategy string
 
 const (
 	// BuildStrategyRoutine performs the build in a routine (will be executed as a process inside the same Camel K operator `Pod`).
-	// A routine may be preferred to a `pod` strategy since it reuse the Maven repository dependency cached locally. It is executed as
+	// A routine may be preferred to a `pod` strategy since it is in general quicker to execute. It is executed as
 	// a parallel process, so you may need to consider the quantity of concurrent build process running simultaneously.
+	// Only available for Quarkus JVM mode.
 	BuildStrategyRoutine BuildStrategy = "routine"
-	// BuildStrategyPod performs the build in a `Pod` (will schedule a new builder ephemeral `Pod` which will take care of the build action).
-	// This strategy has the limitation that every build will have to download all the dependencies required by the Maven build.
+	// BuildStrategyPod performs the build in a `Pod` (will schedule a new builder `Pod` which will take care of the build action).
+	// This strategy has the limitation that every build will have to download all the dependencies required by the Maven build which should be
+	// mitigated by the presence of a Maven proxy.
+	// Available for both Quarkus JVM and Native mode.
 	BuildStrategyPod BuildStrategy = "pod"
+
+	// BuildOrderStrategyFIFO performs the builds with first in first out strategy based on the creation timestamp.
+	// The strategy allows builds to run in parallel to each other but oldest builds will be run first.
+	BuildOrderStrategyFIFO BuildOrderStrategy = "fifo"
+	// BuildOrderStrategyDependencies runs builds ordered by its required dependencies.
+	// Strategy looks at the list of dependencies required by an Integration and queues builds that may reuse base images produced by other
+	// scheduled builds in order to leverage the incremental build option. The strategy allows non-matching builds to run in parallel to each other.
+	BuildOrderStrategyDependencies BuildOrderStrategy = "dependencies"
+	// BuildOrderStrategySequential runs builds strictly sequential so that only one single build per operator namespace is running at a time.
+	BuildOrderStrategySequential BuildOrderStrategy = "sequential"
 )
 
 // BuildStrategies is a list of strategies allowed for the build
@@ -56,6 +90,17 @@ var BuildStrategies = []BuildStrategy{
 	BuildStrategyPod,
 }
 
+// BuildOrderStrategy specifies how builds are reconciled and queued.
+// +kubebuilder:validation:Enum=dependencies;fifo;sequential
+type BuildOrderStrategy string
+
+// BuildOrderStrategies is a list of order strategies allowed for the build
+var BuildOrderStrategies = []BuildOrderStrategy{
+	BuildOrderStrategyFIFO,
+	BuildOrderStrategyDependencies,
+	BuildOrderStrategySequential,
+}
+
 // ConfigurationSpec represents a generic configuration specification
 type ConfigurationSpec struct {
 	// represents the type of configuration, ie: property, configmap, secret, ...
@@ -223,7 +268,7 @@ type TraitConfiguration struct {
 // RawMessage is a raw encoded JSON value.
 // It implements Marshaler and Unmarshaler and can
 // be used to delay JSON decoding or precompute a JSON encoding.
-// +kubebuilder:validation:Type=object
+// +kubebuilder:validation:Type=""
 // +kubebuilder:validation:Format=""
 // +kubebuilder:pruning:PreserveUnknownFields
 type RawMessage []byte
@@ -335,29 +380,6 @@ const (
 	RuntimeProviderQuarkus RuntimeProvider = "quarkus"
 )
 
-// ResourceSpec represent an attached resource which will be materialized as a file on the running `Pod`
-// TODO: we should deprecate in future releases in favour of mount, openapi or camel traits
-type ResourceSpec struct {
-	// the content of the resource
-	DataSpec `json:",inline"`
-	// the kind of data to expect
-	Type ResourceType `json:"type,omitempty"`
-	// the mount path on destination `Pod`
-	MountPath string `json:"mountPath,omitempty"`
-}
-
-// ResourceType defines a kind of resource
-type ResourceType string
-
-const (
-	// ResourceTypeData represents a generic data resource (text or binary)
-	ResourceTypeData ResourceType = "data"
-	// ResourceTypeConfig represents a configuration resource (text only)
-	ResourceTypeConfig ResourceType = "config"
-	// ResourceTypeOpenAPI represents an OpenAPI specification resource
-	ResourceTypeOpenAPI ResourceType = "openapi"
-)
-
 // SourceSpec defines the configuration for one or more routes to be executed in a certain Camel DSL language
 type SourceSpec struct {
 	// contains configuration related to the source code
