@@ -18,13 +18,11 @@ limitations under the License.
 package client
 
 import (
+	"errors"
 	"fmt"
-	"io/ioutil"
 	"os"
 	"path/filepath"
 
-	user "github.com/mitchellh/go-homedir"
-	"github.com/pkg/errors"
 	"github.com/sirupsen/logrus"
 	"k8s.io/client-go/scale"
 
@@ -43,11 +41,11 @@ import (
 	"sigs.k8s.io/controller-runtime/pkg/client/config"
 	"sigs.k8s.io/controller-runtime/pkg/manager"
 
-	"github.com/apache/camel-k/pkg/apis"
-	camel "github.com/apache/camel-k/pkg/client/camel/clientset/versioned"
-	camelv1 "github.com/apache/camel-k/pkg/client/camel/clientset/versioned/typed/camel/v1"
-	camelv1alpha1 "github.com/apache/camel-k/pkg/client/camel/clientset/versioned/typed/camel/v1alpha1"
-	"github.com/apache/camel-k/pkg/util"
+	"github.com/apache/camel-k/v2/pkg/apis"
+	camel "github.com/apache/camel-k/v2/pkg/client/camel/clientset/versioned"
+	camelv1 "github.com/apache/camel-k/v2/pkg/client/camel/clientset/versioned/typed/camel/v1"
+	camelv1alpha1 "github.com/apache/camel-k/v2/pkg/client/camel/clientset/versioned/typed/camel/v1alpha1"
+	"github.com/apache/camel-k/v2/pkg/util"
 )
 
 const (
@@ -212,7 +210,7 @@ func initialize(kubeconfig string) {
 }
 
 func getDefaultKubeConfigFile() (string, error) {
-	dir, err := user.Dir()
+	dir, err := os.UserHomeDir()
 	if err != nil {
 		return "", err
 	}
@@ -296,7 +294,7 @@ func shouldUseContainerMode() (bool, error) {
 func getNamespaceFromKubernetesContainer() (string, error) {
 	var nsba []byte
 	var err error
-	if nsba, err = ioutil.ReadFile(inContainerNamespaceFile); err != nil {
+	if nsba, err = os.ReadFile(inContainerNamespaceFile); err != nil {
 		return "", err
 	}
 	return string(nsba), nil
