@@ -18,13 +18,15 @@ limitations under the License.
 package cmd
 
 import (
+	"os"
 	"testing"
 
-	v1 "github.com/apache/camel-k/pkg/apis/camel/v1"
-	"github.com/apache/camel-k/pkg/platform"
-	"github.com/apache/camel-k/pkg/util/test"
+	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
+	"github.com/apache/camel-k/v2/pkg/platform"
+	"github.com/apache/camel-k/v2/pkg/util/test"
 	"github.com/spf13/cobra"
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 )
 
 const cmdBind = "bind"
@@ -57,7 +59,7 @@ func TestBindOutputJSON(t *testing.T) {
 	assert.Equal(t, "json", buildCmdOptions.OutputFormat)
 
 	assert.Nil(t, err)
-	assert.Equal(t, `{"kind":"KameletBinding","apiVersion":"camel.apache.org/v1alpha1","metadata":{"name":"my-to-my","creationTimestamp":null,"annotations":{"camel.apache.org/operator.id":"camel-k"}},"spec":{"source":{"uri":"my:src"},"sink":{"uri":"my:dst"}},"status":{}}`, output)
+	assert.Equal(t, `{"kind":"Pipe","apiVersion":"camel.apache.org/v1","metadata":{"name":"my-to-my","creationTimestamp":null,"annotations":{"camel.apache.org/operator.id":"camel-k"}},"spec":{"source":{"uri":"my:src"},"sink":{"uri":"my:dst"}},"status":{}}`, output)
 }
 
 func TestBindOutputYAML(t *testing.T) {
@@ -66,8 +68,8 @@ func TestBindOutputYAML(t *testing.T) {
 	assert.Equal(t, "yaml", buildCmdOptions.OutputFormat)
 
 	assert.Nil(t, err)
-	assert.Equal(t, `apiVersion: camel.apache.org/v1alpha1
-kind: KameletBinding
+	assert.Equal(t, `apiVersion: camel.apache.org/v1
+kind: Pipe
 metadata:
   annotations:
     camel.apache.org/operator.id: camel-k
@@ -97,8 +99,8 @@ func TestBindErrorHandlerDLCKamelet(t *testing.T) {
 	assert.Equal(t, "yaml", buildCmdOptions.OutputFormat)
 
 	assert.Nil(t, err)
-	assert.Equal(t, `apiVersion: camel.apache.org/v1alpha1
-kind: KameletBinding
+	assert.Equal(t, `apiVersion: camel.apache.org/v1
+kind: Pipe
 metadata:
   annotations:
     camel.apache.org/operator.id: camel-k
@@ -111,7 +113,7 @@ spec:
         properties:
           my-prop: value
         ref:
-          apiVersion: camel.apache.org/v1alpha1
+          apiVersion: camel.apache.org/v1
           kind: Kamelet
           name: my-kamelet
   sink:
@@ -129,8 +131,8 @@ func TestBindErrorHandlerNone(t *testing.T) {
 	assert.Equal(t, "yaml", buildCmdOptions.OutputFormat)
 
 	assert.Nil(t, err)
-	assert.Equal(t, `apiVersion: camel.apache.org/v1alpha1
-kind: KameletBinding
+	assert.Equal(t, `apiVersion: camel.apache.org/v1
+kind: Pipe
 metadata:
   annotations:
     camel.apache.org/operator.id: camel-k
@@ -154,8 +156,8 @@ func TestBindErrorHandlerLog(t *testing.T) {
 	assert.Equal(t, "yaml", buildCmdOptions.OutputFormat)
 
 	assert.Nil(t, err)
-	assert.Equal(t, `apiVersion: camel.apache.org/v1alpha1
-kind: KameletBinding
+	assert.Equal(t, `apiVersion: camel.apache.org/v1
+kind: Pipe
 metadata:
   annotations:
     camel.apache.org/operator.id: camel-k
@@ -178,8 +180,8 @@ func TestBindTraits(t *testing.T) {
 	assert.Equal(t, "yaml", buildCmdOptions.OutputFormat)
 
 	assert.Nil(t, err)
-	assert.Equal(t, `apiVersion: camel.apache.org/v1alpha1
-kind: KameletBinding
+	assert.Equal(t, `apiVersion: camel.apache.org/v1
+kind: Pipe
 metadata:
   annotations:
     camel.apache.org/operator.id: camel-k
@@ -211,8 +213,8 @@ func TestBindSteps(t *testing.T) {
 	assert.Equal(t, "yaml", buildCmdOptions.OutputFormat)
 
 	assert.Nil(t, err)
-	assert.Equal(t, `apiVersion: camel.apache.org/v1alpha1
-kind: KameletBinding
+	assert.Equal(t, `apiVersion: camel.apache.org/v1
+kind: Pipe
 metadata:
   annotations:
     camel.apache.org/operator.id: camel-k
@@ -245,3 +247,14 @@ func TestBindServiceAccountName(t *testing.T) {
 	assert.Nil(t, err)
 	assert.Contains(t, output, "serviceAccountName: my-service-account")
 }
+
+func TestBindOutputWithoutKubernetesCluster(t *testing.T) {
+	tmpFile, err := os.CreateTemp("", "camel-k-kubeconfig-*")
+	require.NoError(t, err)
+
+	bindCmdOptions, bindCmd, _ := initializeBindCmdOptions(t)
+	bindCmdOptions._client = nil // remove the default fake client which can bypass this test
+	bindCmdOptions.KubeConfig = tmpFile.Name()
+	_, err = test.ExecuteCommand(bindCmd, cmdBind, "my:src", "my:dst", "-o", "yaml")
+	require.NoError(t, err)
+}
