@@ -19,16 +19,16 @@ package cmd
 
 import (
 	"context"
+	"errors"
 	"fmt"
 	"io"
 	"os"
 	"regexp"
-	"strconv"
 	"strings"
 	"time"
 
-	platformutil "github.com/apache/camel-k/pkg/platform"
-	"github.com/pkg/errors"
+	platformutil "github.com/apache/camel-k/v2/pkg/platform"
+
 	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
 
@@ -42,17 +42,17 @@ import (
 
 	ctrl "sigs.k8s.io/controller-runtime/pkg/client"
 
-	v1 "github.com/apache/camel-k/pkg/apis/camel/v1"
-	"github.com/apache/camel-k/pkg/builder"
-	"github.com/apache/camel-k/pkg/client"
-	"github.com/apache/camel-k/pkg/install"
-	"github.com/apache/camel-k/pkg/util"
-	"github.com/apache/camel-k/pkg/util/kubernetes"
-	"github.com/apache/camel-k/pkg/util/maven"
-	"github.com/apache/camel-k/pkg/util/olm"
-	"github.com/apache/camel-k/pkg/util/patch"
-	"github.com/apache/camel-k/pkg/util/registry"
-	"github.com/apache/camel-k/pkg/util/watch"
+	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
+	"github.com/apache/camel-k/v2/pkg/builder"
+	"github.com/apache/camel-k/v2/pkg/client"
+	"github.com/apache/camel-k/v2/pkg/install"
+	"github.com/apache/camel-k/v2/pkg/util"
+	"github.com/apache/camel-k/v2/pkg/util/kubernetes"
+	"github.com/apache/camel-k/v2/pkg/util/maven"
+	"github.com/apache/camel-k/v2/pkg/util/olm"
+	"github.com/apache/camel-k/v2/pkg/util/patch"
+	"github.com/apache/camel-k/v2/pkg/util/registry"
+	"github.com/apache/camel-k/v2/pkg/util/watch"
 )
 
 const installCommand = "install"
@@ -72,7 +72,7 @@ func newCmdInstall(rootCmdOptions *RootCmdOptions) (*cobra.Command, *installCmdO
 			}
 			if err := options.install(cmd, args); err != nil {
 				if k8serrors.IsAlreadyExists(err) {
-					return errors.Wrap(err, "Camel K seems already installed (use the --force option to overwrite existing resources)")
+					return fmt.Errorf("camel K seems already installed (use the --force option to overwrite existing resources): %w", err)
 				}
 				return err
 			}
@@ -107,14 +107,12 @@ func newCmdInstall(rootCmdOptions *RootCmdOptions) (*cobra.Command, *installCmdO
 	cmd.Flags().String("operator-image", "", "Set the operator Image used for the operator deployment")
 	cmd.Flags().String("operator-image-pull-policy", "", "Set the operator ImagePullPolicy used for the operator deployment")
 	cmd.Flags().String("build-strategy", "", "Set the build strategy")
+	cmd.Flags().String("build-order-strategy", "", "Set the build order strategy")
 	cmd.Flags().String("build-publish-strategy", "", "Set the build publish strategy")
 	cmd.Flags().StringArray("build-publish-strategy-option", nil, "Add a build publish strategy option, as <name=value>")
 	cmd.Flags().String("build-timeout", "", "Set how long the build process can last")
 	cmd.Flags().String("trait-profile", "", "The profile to use for traits")
 
-	// Kaniko
-	cmd.Flags().Bool("kaniko-build-cache", false, "To enable or disable the Kaniko cache. Deprecated use --build-publish-strategy-option KanikoBuildCacheEnabled=true instead")
-
 	// OLM
 	cmd.Flags().Bool("olm", true, "Try to install everything via OLM (Operator Lifecycle Manager) if available")
 	cmd.Flags().String("olm-operator-name", "", "Name of the Camel K operator in the OLM source or marketplace")
@@ -143,13 +141,18 @@ func newCmdInstall(rootCmdOptions *RootCmdOptions) (*cobra.Command, *installCmdO
 	cmd.Flags().Bool("monitoring", false, "To enable or disable the operator monitoring")
 	cmd.Flags().Int("monitoring-port", 8080, "The port of the metrics endpoint")
 
+	// debugging
+	cmd.Flags().Bool("debugging", false, "To enable or disable the operator debugging")
+	cmd.Flags().Int("debugging-port", 4040, "The port of the debugger")
+	cmd.Flags().String("debugging-path", "/usr/local/bin/kamel", "The path to the kamel executable file")
+
 	// Operator settings
 	cmd.Flags().StringArray("toleration", nil, "Add a Toleration to the operator Pod")
 	cmd.Flags().StringArray("node-selector", nil, "Add a NodeSelector to the operator Pod")
 	cmd.Flags().StringArray("operator-resources", nil, "Define the resources requests and limits assigned to the operator Pod as <requestType.requestResource=value> (i.e., limits.memory=256Mi)")
 	cmd.Flags().StringArray("operator-env-vars", nil, "Add an environment variable to set in the operator Pod(s), as <name=value>")
 	cmd.Flags().StringP("log-level", "z", "info", "The level of operator logging (default - info): info or 0, debug or 1")
-	cmd.Flags().Int("max-running-builds", 0, "Maximum number of parallel running builds")
+	cmd.Flags().Int("max-running-pipelines", 0, "Maximum number of parallel running pipelines")
 
 	// save
 	cmd.Flags().Bool("save", false, "Save the install parameters into the default kamel configuration file (kamel-config.yaml)")
@@ -159,19 +162,18 @@ func newCmdInstall(rootCmdOptions *RootCmdOptions) (*cobra.Command, *installCmdO
 
 type installCmdOptions struct {
 	*RootCmdOptions
-	Wait                     bool `mapstructure:"wait"`
-	ClusterSetupOnly         bool `mapstructure:"cluster-setup"`
-	SkipOperatorSetup        bool `mapstructure:"skip-operator-setup"`
-	SkipClusterSetup         bool `mapstructure:"skip-cluster-setup"`
-	SkipRegistrySetup        bool `mapstructure:"skip-registry-setup"`
-	SkipDefaultKameletsSetup bool `mapstructure:"skip-default-kamelets-setup"`
-	ExampleSetup             bool `mapstructure:"example"`
-	Global                   bool `mapstructure:"global"`
-	// Deprecated: use the BuildPublishStrategyOption "KanikoBuildCacheEnabled" instead
-	KanikoBuildCache            bool     `mapstructure:"kaniko-build-cache"`
-	Save                        bool     `mapstructure:"save" kamel:"omitsave"`
-	Force                       bool     `mapstructure:"force"`
-	Olm                         bool     `mapstructure:"olm"`
+	Wait                        bool `mapstructure:"wait"`
+	ClusterSetupOnly            bool `mapstructure:"cluster-setup"`
+	SkipOperatorSetup           bool `mapstructure:"skip-operator-setup"`
+	SkipClusterSetup            bool `mapstructure:"skip-cluster-setup"`
+	SkipRegistrySetup           bool `mapstructure:"skip-registry-setup"`
+	SkipDefaultKameletsSetup    bool `mapstructure:"skip-default-kamelets-setup"`
+	ExampleSetup                bool `mapstructure:"example"`
+	Global                      bool `mapstructure:"global"`
+	Save                        bool `mapstructure:"save" kamel:"omitsave"`
+	Force                       bool `mapstructure:"force"`
+	Olm                         bool `mapstructure:"olm"`
+	olmOptions                  olm.Options
 	ClusterType                 string   `mapstructure:"cluster-type"`
 	OutputFormat                string   `mapstructure:"output"`
 	RuntimeVersion              string   `mapstructure:"runtime-version"`
@@ -180,6 +182,7 @@ type installCmdOptions struct {
 	OperatorImage               string   `mapstructure:"operator-image"`
 	OperatorImagePullPolicy     string   `mapstructure:"operator-image-pull-policy"`
 	BuildStrategy               string   `mapstructure:"build-strategy"`
+	BuildOrderStrategy          string   `mapstructure:"build-order-strategy"`
 	BuildPublishStrategy        string   `mapstructure:"build-publish-strategy"`
 	BuildPublishStrategyOptions []string `mapstructure:"build-publish-strategy-options"`
 	BuildTimeout                string   `mapstructure:"build-timeout"`
@@ -191,21 +194,21 @@ type installCmdOptions struct {
 	MavenCASecret               string   `mapstructure:"maven-ca-secret"`
 	MavenCLIOptions             []string `mapstructure:"maven-cli-options"`
 	HealthPort                  int32    `mapstructure:"health-port"`
-	MaxRunningBuilds            int32    `mapstructure:"max-running-builds"`
+	MaxRunningBuilds            int32    `mapstructure:"max-running-pipelines"`
 	Monitoring                  bool     `mapstructure:"monitoring"`
 	MonitoringPort              int32    `mapstructure:"monitoring-port"`
+	Debugging                   bool     `mapstructure:"debugging"`
+	DebuggingPort               int32    `mapstructure:"debugging-port"`
+	DebuggingPath               string   `mapstructure:"debugging-path"`
 	TraitProfile                string   `mapstructure:"trait-profile"`
 	Tolerations                 []string `mapstructure:"tolerations"`
 	NodeSelectors               []string `mapstructure:"node-selectors"`
 	ResourcesRequirements       []string `mapstructure:"operator-resources"`
 	LogLevel                    string   `mapstructure:"log-level"`
 	EnvVars                     []string `mapstructure:"operator-env-vars"`
-
-	registry         v1.RegistrySpec
-	registryAuth     registry.Auth
-	RegistryAuthFile string `mapstructure:"registry-auth-file"`
-
-	olmOptions olm.Options
+	registry                    v1.RegistrySpec
+	registryAuth                registry.Auth
+	RegistryAuthFile            string `mapstructure:"registry-auth-file"`
 }
 
 func (o *installCmdOptions) install(cmd *cobra.Command, _ []string) error {
@@ -277,8 +280,8 @@ func (o *installCmdOptions) tryInstallViaOLM(
 		return false, err
 	}
 	if olmAvailable, err := olm.IsAPIAvailable(o.Context, olmClient, o.Namespace); err != nil {
-		return false, errors.Wrap(err,
-			"error while checking OLM availability. Run with '--olm=false' to skip this check")
+		return false, fmt.Errorf("error while checking OLM availability. Run with '--olm=false' to skip this check: %w", err)
+
 	} else if !olmAvailable {
 		fmt.Fprintln(cmd.OutOrStdout(), "OLM is not available in the cluster. Fallback to regular installation.")
 		return false, nil
@@ -286,13 +289,13 @@ func (o *installCmdOptions) tryInstallViaOLM(
 
 	if hasPermission, err := olm.HasPermissionToInstall(o.Context, olmClient,
 		o.Namespace, o.Global, o.olmOptions); err != nil {
-		return false, errors.Wrap(err,
-			"error while checking permissions to install operator via OLM. Run with '--olm=false' to skip this check")
+		return false, fmt.Errorf("error while checking permissions to install operator via OLM. Run with '--olm=false' to skip this check: %w", err)
+
 	} else if !hasPermission {
 		return false, errors.New(
 			"OLM is available but current user has not enough permissions to create the operator. " +
 				"You can either ask your administrator to provide permissions (preferred) " +
-				"or run the install command with the '--olm=false' flag.")
+				"or run the install command with the '--olm=false' flag")
 	}
 
 	// Install or collect via OLM
@@ -354,7 +357,7 @@ func (o *installCmdOptions) installOperator(cmd *cobra.Command, output *kubernet
 	}
 
 	// Set up IntegrationPlatform
-	platform, err := o.setupIntegrationPlatform(cmd, c, namespace, platformName, registrySecretName, output)
+	platform, err := o.setupIntegrationPlatform(c, namespace, platformName, registrySecretName, output)
 	if err != nil {
 		return err
 	}
@@ -426,6 +429,11 @@ func (o *installCmdOptions) setupOperator(
 			Enabled: o.Monitoring,
 			Port:    o.MonitoringPort,
 		},
+		Debugging: install.OperatorDebuggingConfiguration{
+			Enabled: o.Debugging,
+			Port:    o.DebuggingPort,
+			Path:    o.DebuggingPath,
+		},
 		Tolerations:           o.Tolerations,
 		NodeSelectors:         o.NodeSelectors,
 		ResourcesRequirements: o.ResourcesRequirements,
@@ -460,8 +468,7 @@ func (o *installCmdOptions) setupRegistrySecret(c client.Client, namespace strin
 	return "", nil
 }
 
-func (o *installCmdOptions) setupIntegrationPlatform(
-	cmd *cobra.Command, c client.Client, namespace string, platformName string, registrySecretName string,
+func (o *installCmdOptions) setupIntegrationPlatform(c client.Client, namespace string, platformName string, registrySecretName string,
 	output *kubernetes.Collection,
 ) (*v1.IntegrationPlatform, error) {
 	platform, err := install.NewPlatform(o.Context, c, o.ClusterType, o.SkipRegistrySetup, o.registry, platformName)
@@ -517,7 +524,10 @@ func (o *installCmdOptions) setupIntegrationPlatform(
 		platform.Spec.Build.BaseImage = o.BaseImage
 	}
 	if o.BuildStrategy != "" {
-		platform.Spec.Build.BuildStrategy = v1.BuildStrategy(o.BuildStrategy)
+		platform.Spec.Build.BuildConfiguration.Strategy = v1.BuildStrategy(o.BuildStrategy)
+	}
+	if o.BuildOrderStrategy != "" {
+		platform.Spec.Build.BuildConfiguration.OrderStrategy = v1.BuildOrderStrategy(o.BuildOrderStrategy)
 	}
 	if o.BuildPublishStrategy != "" {
 		platform.Spec.Build.PublishStrategy = v1.IntegrationPlatformBuildPublishStrategy(o.BuildPublishStrategy)
@@ -580,10 +590,6 @@ func (o *installCmdOptions) setupIntegrationPlatform(
 			}
 		}
 	}
-	if platform.Spec.Build.PublishStrategy == v1.IntegrationPlatformBuildPublishStrategyKaniko && cmd.Flags().Lookup("kaniko-build-cache").Changed {
-		fmt.Fprintln(cmd.OutOrStdout(), "Warn: the flag --kaniko-build-cache is deprecated, use --build-publish-strategy-option KanikoBuildCacheEnabled=true instead")
-		platform.Spec.Build.AddOption(builder.KanikoBuildCacheEnabled, strconv.FormatBool(o.KanikoBuildCache))
-	}
 	if len(o.BuildPublishStrategyOptions) > 0 {
 		if err = o.addBuildPublishStrategyOptions(&platform.Spec.Build); err != nil {
 			return nil, err
@@ -596,7 +602,7 @@ func (o *installCmdOptions) setupIntegrationPlatform(
 	}
 
 	if err := install.IntegrationPlatformViewerRole(o.Context, c, namespace); err != nil && !k8serrors.IsAlreadyExists(err) {
-		return nil, errors.Wrap(err, "Error while installing global IntegrationPlatform viewer role")
+		return nil, fmt.Errorf("error while installing global IntegrationPlatform viewer role: %w", err)
 	}
 
 	if o.ExampleSetup {
@@ -727,7 +733,7 @@ func (o *installCmdOptions) validate(_ *cobra.Command, _ []string) error {
 		if err != nil {
 			result = multierr.Append(result, err)
 		} else if nfo.IsDir() {
-			result = multierr.Append(result, errors.Wrapf(err, "registry file cannot be a directory: %s", o.RegistryAuthFile))
+			result = multierr.Append(result, fmt.Errorf("registry file cannot be a directory: %s: %w", o.RegistryAuthFile, err))
 		}
 	}
 
@@ -748,6 +754,23 @@ func (o *installCmdOptions) validate(_ *cobra.Command, _ []string) error {
 		}
 	}
 
+	if o.BuildOrderStrategy != "" {
+		found := false
+		for _, s := range v1.BuildOrderStrategies {
+			if string(s) == o.BuildOrderStrategy {
+				found = true
+				break
+			}
+		}
+		if !found {
+			var strategies []string
+			for _, s := range v1.BuildOrderStrategies {
+				strategies = append(strategies, string(s))
+			}
+			return fmt.Errorf("unknown build order strategy: %s. One of [%s] is expected", o.BuildOrderStrategy, strings.Join(strategies, ", "))
+		}
+	}
+
 	if o.BuildPublishStrategy != "" {
 		found := false
 		for _, s := range v1.IntegrationPlatformBuildPublishStrategies {
@@ -769,15 +792,15 @@ func (o *installCmdOptions) validate(_ *cobra.Command, _ []string) error {
 }
 
 // addBuildPublishStrategyOptions parses and adds all the build publish strategy options to the given IntegrationPlatformBuildSpec.
-func (o *installCmdOptions) addBuildPublishStrategyOptions(build *v1.IntegrationPlatformBuildSpec) error {
+func (o *installCmdOptions) addBuildPublishStrategyOptions(pipeline *v1.IntegrationPlatformBuildSpec) error {
 	for _, option := range o.BuildPublishStrategyOptions {
 		kv := strings.Split(option, "=")
 		if len(kv) == 2 {
 			key := kv[0]
-			if builder.IsSupportedPublishStrategyOption(build.PublishStrategy, key) {
-				build.AddOption(key, kv[1])
+			if builder.IsSupportedPublishStrategyOption(pipeline.PublishStrategy, key) {
+				pipeline.AddOption(key, kv[1])
 			} else {
-				return fmt.Errorf("build publish strategy option '%s' not supported. %s", option, supportedOptionsAsString(build.PublishStrategy))
+				return fmt.Errorf("build publish strategy option '%s' not supported. %s", option, supportedOptionsAsString(pipeline.PublishStrategy))
 			}
 		} else {
 			return fmt.Errorf("build publish strategy option '%s' not in the expected format (name=value)", option)
@@ -886,7 +909,7 @@ func createDefaultMavenSettingsConfigMap(ctx context.Context, client client.Clie
 		} else if len(p) != 0 {
 			err = client.Patch(ctx, cm, ctrl.RawPatch(types.MergePatchType, p))
 			if err != nil {
-				return errors.Wrap(err, "error during patch resource")
+				return fmt.Errorf("error during patch resource: %w", err)
 			}
 		}
 	}
