@@ -21,12 +21,12 @@ import (
 	"errors"
 	"fmt"
 
+	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
+
 	"github.com/spf13/cobra"
 	k8errors "k8s.io/apimachinery/pkg/api/errors"
 
 	k8sclient "sigs.k8s.io/controller-runtime/pkg/client"
-
-	"github.com/apache/camel-k/pkg/apis/camel/v1alpha1"
 )
 
 func newKameletDeleteCmd(rootCmdOptions *RootCmdOptions) (*cobra.Command, *kameletDeleteCommandOptions) {
@@ -35,19 +35,14 @@ func newKameletDeleteCmd(rootCmdOptions *RootCmdOptions) (*cobra.Command, *kamel
 	}
 
 	cmd := cobra.Command{
-		Use:     "delete <name>",
-		Short:   "Delete a Kamelet",
-		Long:    `Delete a Kamelet.`,
+		Use:     "delete [Kamelet1] [Kamelet2] ...",
+		Short:   "Delete Kamelets deployed on Kubernetes",
 		PreRunE: decode(&options),
 		RunE: func(cmd *cobra.Command, args []string) error {
 			if err := options.validate(args); err != nil {
 				return err
 			}
-			if err := options.run(cmd, args); err != nil {
-				fmt.Fprintln(cmd.ErrOrStderr(), err.Error())
-			}
-
-			return nil
+			return options.run(cmd, args)
 		},
 	}
 
@@ -63,10 +58,10 @@ type kameletDeleteCommandOptions struct {
 
 func (command *kameletDeleteCommandOptions) validate(args []string) error {
 	if command.All && len(args) > 0 {
-		return errors.New("invalid combination: both all flag and named kamelets are set")
+		return errors.New("invalid combination: --all flag is set and at least one kamelet name is provided")
 	}
 	if !command.All && len(args) == 0 {
-		return errors.New("invalid combination: neither all flag nor named kamelets are set")
+		return errors.New("invalid combination: provide one or several kamelet names or set --all flag for all kamelets")
 	}
 
 	return nil
@@ -81,14 +76,14 @@ func (command *kameletDeleteCommandOptions) run(cmd *cobra.Command, args []strin
 	}
 
 	if command.All {
-		klList := v1alpha1.NewKameletList()
+		klList := v1.NewKameletList()
 		if err := c.List(command.Context, &klList, k8sclient.InNamespace(command.Namespace)); err != nil {
 			return err
 		}
 		names = make([]string, 0, len(klList.Items))
 		for _, kl := range klList.Items {
 			// only include non-bundled, non-readonly kamelets
-			if kl.Labels[v1alpha1.KameletBundledLabel] != "true" && kl.Labels[v1alpha1.KameletReadOnlyLabel] != "true" {
+			if kl.Labels[v1.KameletBundledLabel] != "true" && kl.Labels[v1.KameletReadOnlyLabel] != "true" {
 				names = append(names, kl.Name)
 			}
 		}
@@ -109,7 +104,7 @@ func (command *kameletDeleteCommandOptions) delete(cmd *cobra.Command, name stri
 		return err
 	}
 
-	kl := v1alpha1.NewKamelet(command.Namespace, name)
+	kl := v1.NewKamelet(command.Namespace, name)
 	key := k8sclient.ObjectKey{
 		Namespace: command.Namespace,
 		Name:      name,
@@ -124,7 +119,7 @@ func (command *kameletDeleteCommandOptions) delete(cmd *cobra.Command, name stri
 
 	// check that it is not a bundled nor read-only one which is supposed to belong to platform
 	// thus not managed by the end user
-	if kl.Labels[v1alpha1.KameletBundledLabel] == "true" || kl.Labels[v1alpha1.KameletReadOnlyLabel] == "true" {
+	if kl.Labels[v1.KameletBundledLabel] == "true" || kl.Labels[v1.KameletReadOnlyLabel] == "true" {
 		// skip platform Kamelets while deleting all Kamelets
 		if command.All {
 			return nil
