@@ -22,8 +22,8 @@ import (
 	"fmt"
 	"time"
 
-	v1 "github.com/apache/camel-k/pkg/apis/camel/v1"
-	k8slog "github.com/apache/camel-k/pkg/util/kubernetes/log"
+	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
+	k8slog "github.com/apache/camel-k/v2/pkg/util/kubernetes/log"
 	"github.com/spf13/cobra"
 	k8errors "k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
