@@ -19,22 +19,20 @@ package cmd
 
 import (
 	"context"
+	"errors"
 	"fmt"
 	"reflect"
 	"regexp"
 	"strings"
 
-	"github.com/pkg/errors"
-
-	v1 "github.com/apache/camel-k/pkg/apis/camel/v1"
-	traitv1 "github.com/apache/camel-k/pkg/apis/camel/v1/trait"
-	"github.com/apache/camel-k/pkg/apis/camel/v1alpha1"
-	"github.com/apache/camel-k/pkg/client"
-	"github.com/apache/camel-k/pkg/trait"
-	"github.com/apache/camel-k/pkg/util/camel"
-	"github.com/apache/camel-k/pkg/util/kamelets"
-	"github.com/apache/camel-k/pkg/util/kubernetes"
-	"github.com/apache/camel-k/pkg/util/resource"
+	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
+	traitv1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1/trait"
+	"github.com/apache/camel-k/v2/pkg/client"
+	"github.com/apache/camel-k/v2/pkg/trait"
+	"github.com/apache/camel-k/v2/pkg/util/camel"
+	"github.com/apache/camel-k/v2/pkg/util/kamelets"
+	"github.com/apache/camel-k/v2/pkg/util/kubernetes"
+	"github.com/apache/camel-k/v2/pkg/util/resource"
 	"github.com/spf13/cobra"
 	corev1 "k8s.io/api/core/v1"
 	rbacv1 "k8s.io/api/rbac/v1"
@@ -52,8 +50,8 @@ func newCmdPromote(rootCmdOptions *RootCmdOptions) (*cobra.Command, *promoteCmdO
 	}
 	cmd := cobra.Command{
 		Use:     "promote my-it --to [namespace]",
-		Short:   "Promote an Integration/KameletBinding from an environment to another",
-		Long:    "Promote an Integration/KameletBinding from an environment to another, for example from a Development environment to a Production environment",
+		Short:   "Promote an Integration/Pipe from an environment to another",
+		Long:    "Promote an Integration/Pipe from an environment to another, for example from a Development environment to a Production environment",
 		PreRunE: decode(&options),
 		RunE:    options.run,
 	}
@@ -72,7 +70,7 @@ type promoteCmdOptions struct {
 
 func (o *promoteCmdOptions) validate(_ *cobra.Command, args []string) error {
 	if len(args) != 1 {
-		return errors.New("promote expects an Integration/KameletBinding name argument")
+		return errors.New("promote expects an Integration/Pipe name argument")
 	}
 	if o.To == "" {
 		return errors.New("promote expects a destination namespace as --to argument")
@@ -88,54 +86,54 @@ func (o *promoteCmdOptions) run(cmd *cobra.Command, args []string) error {
 	name := args[0]
 	c, err := o.GetCmdClient()
 	if err != nil {
-		return errors.Wrap(err, "could not retrieve cluster client")
+		return fmt.Errorf("could not retrieve cluster client: %w", err)
 	}
 	opSource, err := operatorInfo(o.Context, c, o.Namespace)
 	if err != nil {
-		return errors.Wrap(err, "could not retrieve info for Camel K operator source")
+		return fmt.Errorf("could not retrieve info for Camel K operator source: %w", err)
 	}
 	opDest, err := operatorInfo(o.Context, c, o.To)
 	if err != nil {
-		return errors.Wrap(err, "could not retrieve info for Camel K operator destination")
+		return fmt.Errorf("could not retrieve info for Camel K operator destination: %w", err)
 	}
 
 	err = checkOpsCompatibility(cmd, opSource, opDest)
 	if err != nil {
-		return errors.Wrap(err, "could not verify operators compatibility")
+		return fmt.Errorf("could not verify operators compatibility: %w", err)
 	}
-	promoteKameletBinding := false
+	promotePipe := false
 	var sourceIntegration *v1.Integration
-	// We first look if a KameletBinding with the name exists
-	sourceKameletBinding, err := o.getKameletBinding(c, name)
+	// We first look if a Pipe with the name exists
+	sourcePipe, err := o.getPipe(c, name)
 	if err != nil && !k8serrors.IsNotFound(err) {
-		return errors.Wrap(err, "problems looking for KameletBinding "+name)
+		return fmt.Errorf("problems looking for Pipe "+name+": %w", err)
 	}
-	if sourceKameletBinding != nil {
-		promoteKameletBinding = true
+	if sourcePipe != nil {
+		promotePipe = true
 	}
 	sourceIntegration, err = o.getIntegration(c, name)
 	if err != nil {
-		return errors.Wrap(err, "could not get Integration "+name)
+		return fmt.Errorf("could not get Integration "+name+": %w", err)
 	}
 	if sourceIntegration.Status.Phase != v1.IntegrationPhaseRunning {
 		return fmt.Errorf("could not promote an Integration in %s status", sourceIntegration.Status.Phase)
 	}
 	err = o.validateDestResources(c, sourceIntegration)
 	if err != nil {
-		return errors.Wrap(err, "could not validate destination resources")
+		return fmt.Errorf("could not validate destination resources: %w", err)
 	}
 
-	// KameletBinding promotion
-	if promoteKameletBinding {
-		destKameletBinding := o.editKameletBinding(sourceKameletBinding, sourceIntegration)
+	// Pipe promotion
+	if promotePipe {
+		destPipe := o.editPipe(sourcePipe, sourceIntegration)
 		// Ensure the destination namespace has access to the source namespace images
-		err = addSystemPullerRoleBinding(o.Context, c, sourceIntegration.Namespace, destKameletBinding.Namespace)
+		err = addSystemPullerRoleBinding(o.Context, c, sourceIntegration.Namespace, destPipe.Namespace)
 		if err != nil {
 			return err
 		}
-		replaced, err := o.replaceResource(destKameletBinding)
+		replaced, err := o.replaceResource(destPipe)
 		if o.OutputFormat != "" {
-			return showKameletBindingOutput(cmd, destKameletBinding, o.OutputFormat, c.GetScheme())
+			return showPipeOutput(cmd, destPipe, o.OutputFormat, c.GetScheme())
 		}
 		if !replaced {
 			fmt.Fprintln(cmd.OutOrStdout(), `Promoted Integration "`+name+`" created`)
@@ -153,7 +151,7 @@ func (o *promoteCmdOptions) run(cmd *cobra.Command, args []string) error {
 		return err
 	}
 	if o.OutputFormat != "" {
-		return showIntegrationOutput(cmd, destIntegration, o.OutputFormat, c.GetScheme())
+		return showIntegrationOutput(cmd, destIntegration, o.OutputFormat)
 	}
 	replaced, err := o.replaceResource(destIntegration)
 	if !replaced {
@@ -178,8 +176,8 @@ func checkOpsCompatibility(cmd *cobra.Command, source, dest map[string]string) e
 	return nil
 }
 
-func (o *promoteCmdOptions) getKameletBinding(c client.Client, name string) (*v1alpha1.KameletBinding, error) {
-	it := v1alpha1.NewKameletBinding(o.Namespace, name)
+func (o *promoteCmdOptions) getPipe(c client.Client, name string) (*v1.Pipe, error) {
+	it := v1.NewPipe(o.Namespace, name)
 	key := k8sclient.ObjectKey{
 		Name:      name,
 		Namespace: o.Namespace,
@@ -427,7 +425,7 @@ func existsPv(ctx context.Context, c client.Client, name string, namespace strin
 }
 
 func existsKamelet(ctx context.Context, c client.Client, name string, namespace string) bool {
-	var obj v1alpha1.Kamelet
+	var obj v1.Kamelet
 	key := k8sclient.ObjectKey{
 		Name:      name,
 		Namespace: namespace,
@@ -443,6 +441,8 @@ func (o *promoteCmdOptions) editIntegration(it *v1.Integration) *v1.Integration
 	dst := v1.NewIntegration(o.To, it.Name)
 	contImage := it.Status.Image
 	dst.Spec = *it.Spec.DeepCopy()
+	dst.Annotations = cloneAnnotations(it.Annotations)
+	dst.Labels = cloneLabels(it.Labels)
 	if dst.Spec.Traits.Container == nil {
 		dst.Spec.Traits.Container = &traitv1.ContainerTrait{}
 	}
@@ -450,9 +450,31 @@ func (o *promoteCmdOptions) editIntegration(it *v1.Integration) *v1.Integration
 	return &dst
 }
 
-func (o *promoteCmdOptions) editKameletBinding(kb *v1alpha1.KameletBinding, it *v1.Integration) *v1alpha1.KameletBinding {
-	dst := v1alpha1.NewKameletBinding(o.To, kb.Name)
+// Return all annotations but the ones specific to source (ie, the operator).
+func cloneAnnotations(ann map[string]string) map[string]string {
+	newMap := make(map[string]string)
+	for k, v := range ann {
+		if k != v1.OperatorIDAnnotation {
+			newMap[k] = v
+		}
+	}
+	return newMap
+}
+
+// Return all labels. The method is a reference if in the future we need to apply any filtering.
+func cloneLabels(lbs map[string]string) map[string]string {
+	newMap := make(map[string]string)
+	for k, v := range lbs {
+		newMap[k] = v
+	}
+	return newMap
+}
+
+func (o *promoteCmdOptions) editPipe(kb *v1.Pipe, it *v1.Integration) *v1.Pipe {
+	dst := v1.NewPipe(o.To, kb.Name)
 	dst.Spec = *kb.Spec.DeepCopy()
+	dst.Annotations = cloneAnnotations(kb.Annotations)
+	dst.Labels = cloneLabels(kb.Labels)
 	contImage := it.Status.Image
 	if dst.Spec.Integration == nil {
 		dst.Spec.Integration = &v1.IntegrationSpec{}
@@ -481,11 +503,9 @@ func (o *promoteCmdOptions) replaceResource(res k8sclient.Object) (bool, error)
 	return kubernetes.ReplaceResource(o.Context, o._client, res)
 }
 
-//
 // RoleBinding is required to allow access to images in one namespace
 // by another namespace. Without this on rbac-enabled clusters, the
 // image cannot be pulled.
-//
 func addSystemPullerRoleBinding(ctx context.Context, c client.Client, sourceNS string, destNS string) error {
 	rb := &rbacv1.RoleBinding{
 		TypeMeta: metav1.TypeMeta{
