@@ -20,6 +20,7 @@ package cmd
 import (
 	"archive/zip"
 	"context"
+	"errors"
 
 	// this is needed to generate an SHA1 sum for Jars
 	// #nosec G501
@@ -33,7 +34,6 @@ import (
 	"hash"
 	"io"
 	"io/fs"
-	"io/ioutil"
 	"net/url"
 	"os"
 	"os/signal"
@@ -45,36 +45,35 @@ import (
 
 	spectrum "github.com/container-tools/spectrum/pkg/builder"
 	"github.com/magiconair/properties"
-	"github.com/pkg/errors"
+
 	"github.com/spf13/cobra"
 	"github.com/spf13/pflag"
 
 	corev1 "k8s.io/api/core/v1"
 	k8serrors "k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
-	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/apimachinery/pkg/util/yaml"
 	"k8s.io/cli-runtime/pkg/printers"
+	"k8s.io/client-go/kubernetes/scheme"
 
 	ctrl "sigs.k8s.io/controller-runtime/pkg/client"
 
-	v1 "github.com/apache/camel-k/pkg/apis/camel/v1"
-	"github.com/apache/camel-k/pkg/client"
-	"github.com/apache/camel-k/pkg/cmd/local"
-	"github.com/apache/camel-k/pkg/cmd/source"
-	"github.com/apache/camel-k/pkg/platform"
-	"github.com/apache/camel-k/pkg/trait"
-	"github.com/apache/camel-k/pkg/util"
-	"github.com/apache/camel-k/pkg/util/camel"
-	"github.com/apache/camel-k/pkg/util/defaults"
-	"github.com/apache/camel-k/pkg/util/dsl"
-	"github.com/apache/camel-k/pkg/util/kubernetes"
-	k8slog "github.com/apache/camel-k/pkg/util/kubernetes/log"
-	"github.com/apache/camel-k/pkg/util/maven"
-	"github.com/apache/camel-k/pkg/util/property"
-	"github.com/apache/camel-k/pkg/util/resource"
-	"github.com/apache/camel-k/pkg/util/sync"
-	"github.com/apache/camel-k/pkg/util/watch"
+	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
+	"github.com/apache/camel-k/v2/pkg/client"
+	"github.com/apache/camel-k/v2/pkg/cmd/source"
+	"github.com/apache/camel-k/v2/pkg/platform"
+	"github.com/apache/camel-k/v2/pkg/trait"
+	"github.com/apache/camel-k/v2/pkg/util"
+	"github.com/apache/camel-k/v2/pkg/util/camel"
+	"github.com/apache/camel-k/v2/pkg/util/defaults"
+	"github.com/apache/camel-k/v2/pkg/util/dsl"
+	"github.com/apache/camel-k/v2/pkg/util/kubernetes"
+	k8slog "github.com/apache/camel-k/v2/pkg/util/kubernetes/log"
+	"github.com/apache/camel-k/v2/pkg/util/maven"
+	"github.com/apache/camel-k/v2/pkg/util/property"
+	"github.com/apache/camel-k/v2/pkg/util/resource"
+	"github.com/apache/camel-k/v2/pkg/util/sync"
+	"github.com/apache/camel-k/v2/pkg/util/watch"
 )
 
 const usageDependency = `A dependency that should be included, e.g., "-d camel:mail" for a Camel component, "-d mvn:org.my:app:1.0" for a Maven dependency, "-d http(s)://my-repo/my-dependency.jar|targetPath=<path>&registry=<registry_URL>&skipChecksums=<true>&skipPOM=<true>&classpath=<true>" for custom dependencies located on an http server or "file://localPath[?targetPath=<path>&registry=<registry_URL>&skipChecksums=<true>&skipPOM=<true>&classpath=<true>]" for local files`
@@ -90,7 +89,7 @@ func newCmdRun(rootCmdOptions *RootCmdOptions) (*cobra.Command, *runCmdOptions)
 		Long:              `Deploys and execute a integration pod on Kubernetes.`,
 		Args:              options.validateArgs,
 		PersistentPreRunE: options.decode,
-		PreRunE:           options.preRunE,
+		PreRunE:           options.preRun,
 		RunE:              options.run,
 		PostRunE:          options.postRun,
 		Annotations:       make(map[string]string),
@@ -103,8 +102,8 @@ func newCmdRun(rootCmdOptions *RootCmdOptions) (*cobra.Command, *runCmdOptions)
 	cmd.Flags().StringP("kit", "k", "", "The kit used to run the integration")
 	cmd.Flags().StringArrayP("property", "p", nil, "Add a runtime property or properties file from a path, a config map or a secret (syntax: [my-key=my-value|file:/path/to/my-conf.properties|[configmap|secret]:name])")
 	cmd.Flags().StringArray("build-property", nil, "Add a build time property or properties file from a path, a config map or a secret (syntax: [my-key=my-value|file:/path/to/my-conf.properties|[configmap|secret]:name]])")
-	cmd.Flags().StringArray("config", nil, "Add a runtime configuration from a Configmap, a Secret or a file (syntax: [configmap|secret|file]:name[/key], where name represents the local file path or the configmap/secret name and key optionally represents the configmap/secret key to be filtered)")
-	cmd.Flags().StringArray("resource", nil, "Add a runtime resource from a Configmap, a Secret or a file (syntax: [configmap|secret|file]:name[/key][@path], where name represents the local file path or the configmap/secret name, key optionally represents the configmap/secret key to be filtered and path represents the destination path)")
+	cmd.Flags().StringArray("config", nil, "Add a runtime configuration from a Configmap or a Secret (syntax: [configmap|secret]:name[/key], where name represents the configmap/secret name and key optionally represents the configmap/secret key to be filtered)")
+	cmd.Flags().StringArray("resource", nil, "Add a runtime resource from a Configmap or a Secret (syntax: [configmap|secret]:name[/key][@path], where name represents the configmap/secret name, key optionally represents the configmap/secret key to be filtered and path represents the destination path)")
 	cmd.Flags().StringArray("maven-repository", nil, "Add a maven repository")
 	cmd.Flags().Bool("logs", false, "Print integration logs")
 	cmd.Flags().Bool("sync", false, "Synchronize the local source file with the cluster, republishing at each change")
@@ -167,14 +166,6 @@ type runCmdOptions struct {
 	Force           bool `mapstructure:"force" yaml:",omitempty"`
 }
 
-func (o *runCmdOptions) preRunE(cmd *cobra.Command, args []string) error {
-	if o.OutputFormat != "" {
-		// let the command work in offline mode
-		cmd.Annotations[offlineCommandLabel] = "true"
-	}
-	return o.RootCmdOptions.preRun(cmd, args)
-}
-
 func (o *runCmdOptions) decode(cmd *cobra.Command, args []string) error {
 	// *************************************************************************
 	//
@@ -188,7 +179,7 @@ func (o *runCmdOptions) decode(cmd *cobra.Command, args []string) error {
 	// the values loaded from the second steps belong to a node for which there
 	// are no flags as it is a dynamic node not known when the command hierarchy
 	// is initialized and configured so any flag value is simple ignored and the
-	// struct field takes tha value of the the persisted configuration node.
+	// struct field takes the value of the persisted configuration node.
 	//
 	// *************************************************************************
 
@@ -198,7 +189,12 @@ func (o *runCmdOptions) decode(cmd *cobra.Command, args []string) error {
 		return err
 	}
 
-	if err := o.validate(); err != nil {
+	if o.OutputFormat != "" {
+		// let the command work in offline mode
+		cmd.Annotations[offlineCommandLabel] = "true"
+	}
+
+	if err := o.validate(cmd); err != nil {
 		return err
 	}
 
@@ -234,7 +230,7 @@ func (o *runCmdOptions) decode(cmd *cobra.Command, args []string) error {
 		})
 	}
 
-	return o.validate()
+	return o.validate(cmd)
 }
 
 func (o *runCmdOptions) validateArgs(cmd *cobra.Command, args []string) error {
@@ -243,13 +239,13 @@ func (o *runCmdOptions) validateArgs(cmd *cobra.Command, args []string) error {
 	}
 
 	if _, err := source.Resolve(context.Background(), args, false, cmd); err != nil {
-		return errors.Wrap(err, "One of the provided sources is not reachable")
+		return fmt.Errorf("one of the provided sources is not reachable: %w", err)
 	}
 
 	return nil
 }
 
-func (o *runCmdOptions) validate() error {
+func (o *runCmdOptions) validate(cmd *cobra.Command) error {
 	if o.OperatorID == "" {
 		return fmt.Errorf("cannot use empty operator id")
 	}
@@ -263,7 +259,7 @@ func (o *runCmdOptions) validate() error {
 
 	propertyFiles := filterBuildPropertyFiles(o.Properties)
 	propertyFiles = append(propertyFiles, filterBuildPropertyFiles(o.BuildProperties)...)
-	err := local.ValidatePropertyFiles(propertyFiles)
+	err := validatePropertyFiles(propertyFiles)
 	if err != nil {
 		return err
 	}
@@ -287,19 +283,22 @@ func (o *runCmdOptions) validate() error {
 	}
 
 	for _, openapi := range o.OpenAPIs {
-		// We support only local file and cluster configmaps
-		if !(strings.HasPrefix(openapi, "file:") || strings.HasPrefix(openapi, "configmap:")) {
-			return fmt.Errorf(`invalid openapi specification "%s". It supports only file or configmap`, openapi)
+		// We support only cluster configmaps
+		if !(strings.HasPrefix(openapi, "configmap:")) {
+			return fmt.Errorf(`invalid openapi specification "%s". It supports only configmaps`, openapi)
 		}
 	}
 
-	client, err := o.GetCmdClient()
-	if err != nil {
-		return err
+	var client client.Client
+	if !isOfflineCommand(cmd) {
+		client, err = o.GetCmdClient()
+		if err != nil {
+			return err
+		}
 	}
 	catalog := trait.NewCatalog(client)
 
-	return validateTraits(catalog, o.Traits)
+	return validateTraits(catalog, extractTraitNames(o.Traits))
 }
 
 func filterBuildPropertyFiles(maybePropertyFiles []string) []string {
@@ -314,9 +313,13 @@ func filterBuildPropertyFiles(maybePropertyFiles []string) []string {
 }
 
 func (o *runCmdOptions) run(cmd *cobra.Command, args []string) error {
-	c, err := o.GetCmdClient()
-	if err != nil {
-		return err
+	var c client.Client
+	var err error
+	if !isOfflineCommand(cmd) {
+		c, err = o.GetCmdClient()
+		if err != nil {
+			return err
+		}
 	}
 
 	integration, err := o.createOrUpdateIntegration(cmd, c, args)
@@ -558,26 +561,38 @@ func (o *runCmdOptions) createOrUpdateIntegration(cmd *cobra.Command, c client.C
 	}
 
 	if o.OutputFormat != "" {
-		return nil, showIntegrationOutput(cmd, integration, o.OutputFormat, c.GetScheme())
+		return nil, showIntegrationOutput(cmd, integration, o.OutputFormat)
 	}
 
 	if existing == nil {
 		err = c.Create(o.Context, integration)
+		if err != nil {
+			return nil, err
+		}
 		fmt.Fprintln(cmd.OutOrStdout(), `Integration "`+name+`" created`)
 	} else {
-		err = c.Patch(o.Context, integration, ctrl.MergeFromWithOptions(existing, ctrl.MergeFromWithOptimisticLock{}))
-		fmt.Fprintln(cmd.OutOrStdout(), `Integration "`+name+`" updated`)
-	}
+		patch := ctrl.MergeFrom(existing)
+		d, err := patch.Data(integration)
+		if err != nil {
+			return nil, err
+		}
 
-	if err != nil {
-		return nil, err
+		if string(d) == "{}" {
+			fmt.Fprintln(cmd.OutOrStdout(), `Integration "`+name+`" unchanged`)
+			return integration, nil
+		}
+		err = c.Patch(o.Context, integration, patch)
+		if err != nil {
+			return nil, err
+		}
+		fmt.Fprintln(cmd.OutOrStdout(), `Integration "`+name+`" updated`)
 	}
 
 	return integration, nil
 }
 
-func showIntegrationOutput(cmd *cobra.Command, integration *v1.Integration, outputFormat string, scheme runtime.ObjectTyper) error {
-	printer := printers.NewTypeSetter(scheme)
+func showIntegrationOutput(cmd *cobra.Command, integration *v1.Integration, outputFormat string) error {
+	printer := printers.NewTypeSetter(scheme.Scheme)
 	printer.Delegate = &kubernetes.CLIPrinter{
 		Format: outputFormat,
 	}
@@ -725,15 +740,17 @@ func (o *runCmdOptions) parseAndConvertToTrait(cmd *cobra.Command,
 	c client.Client, integration *v1.Integration, params []string,
 	parse func(string) (*resource.Config, error),
 	convert func(*resource.Config) string,
-	traitParam string) error {
+	traitParam string,
+) error {
 	for _, param := range params {
 		config, err := parse(param)
 		if err != nil {
 			return err
 		}
-		// We try to autogenerate a configmap
-		if _, err := parseConfigAndGenCm(o.Context, cmd, c, config, integration, o.Compression); err != nil {
-			return err
+		if o.OutputFormat == "" {
+			if err := parseConfig(o.Context, cmd, c, config, integration); err != nil {
+				return err
+			}
 		}
 		o.Traits = append(o.Traits, convertToTrait(convert(config), traitParam))
 	}
@@ -801,7 +818,7 @@ func (o *runCmdOptions) applyDependencies(cmd *cobra.Command, c client.Client, i
 				}
 			}
 			if err := o.uploadDependency(platform, item, name, cmd, it); err != nil {
-				return errors.Wrap(err, fmt.Sprintf("Error trying to upload %s to the Image Registry.", item))
+				return fmt.Errorf("error trying to upload %s to the Image Registry.: %w", item, err)
 			}
 		} else {
 			if catalog == nil {
@@ -811,7 +828,7 @@ func (o *runCmdOptions) applyDependencies(cmd *cobra.Command, c client.Client, i
 				// And the validation only warns potential misusages of Camel components at the CLI level,
 				// so strictness of catalog version is not necessary here.
 				var err error
-				catalog, err = local.CreateCamelCatalog(o.Context)
+				catalog, err = createCamelCatalog(o.Context)
 				if err != nil {
 					return err
 				}
@@ -990,7 +1007,7 @@ func (o *runCmdOptions) uploadDependency(platform *v1.IntegrationPlatform, item
 			query := item[idx+1:]
 			options, err := url.ParseQuery(query)
 			if err != nil {
-				return errors.Wrap(err, fmt.Sprintf("invalid http dependency options %s", query))
+				return fmt.Errorf("invalid http dependency options %s: %w", query, err)
 			}
 			o.RegistryOptions = options
 			depURL = item[:idx]
@@ -998,9 +1015,9 @@ func (o *runCmdOptions) uploadDependency(platform *v1.IntegrationPlatform, item
 
 		uri, err := url.Parse(depURL)
 		if err != nil {
-			return errors.Wrap(err, fmt.Sprintf("invalid http dependency url %s", depURL))
+			return fmt.Errorf("invalid http dependency url %s: %w", depURL, err)
 		} else if localPath, err = downloadDependency(o.Context, *uri); err != nil {
-			return errors.Wrap(err, fmt.Sprintf("could not download http dependency %s", depURL))
+			return fmt.Errorf("could not download http dependency %s: %w", depURL, err)
 		}
 		// Remove the temporary file
 		defer os.Remove(localPath)
@@ -1137,7 +1154,7 @@ func (o *runCmdOptions) extractGav(src *zip.File, localPath string, cmd *cobra.C
 		return maven.Dependency{}, false
 	}
 	defer rc.Close()
-	data, err := ioutil.ReadAll(rc)
+	data, err := io.ReadAll(rc)
 	if err != nil {
 		o.PrintfVerboseErrf(cmd, "Error while reading pom.properties from [%s], switching to default: \n %s err \n", localPath, err)
 		return maven.Dependency{}, false
@@ -1196,7 +1213,7 @@ func extractGavFromPom(path string, gav maven.Dependency) maven.Dependency {
 		return gav
 	}
 	defer file.Close()
-	content, err := ioutil.ReadAll(file)
+	content, err := io.ReadAll(file)
 	if err != nil {
 		return gav
 	}
@@ -1315,6 +1332,7 @@ func createDefaultGav(path string, dirName string, integrationName string) (mave
 func isPom(path string) bool {
 	return strings.HasSuffix(path, ".pom") || strings.HasSuffix(path, "pom.xml")
 }
+
 func isJar(path string) bool {
 	return strings.HasSuffix(path, ".jar")
 }
