@@ -20,8 +20,9 @@ package integrationkit
 import (
 	"context"
 	"fmt"
+	"time"
 
-	"k8s.io/apimachinery/pkg/api/errors"
+	k8serrors "k8s.io/apimachinery/pkg/api/errors"
 	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/apimachinery/pkg/runtime/schema"
 	"k8s.io/apimachinery/pkg/types"
@@ -35,13 +36,13 @@ import (
 	"sigs.k8s.io/controller-runtime/pkg/reconcile"
 	"sigs.k8s.io/controller-runtime/pkg/source"
 
-	v1 "github.com/apache/camel-k/pkg/apis/camel/v1"
-	"github.com/apache/camel-k/pkg/client"
-	camelevent "github.com/apache/camel-k/pkg/event"
-	"github.com/apache/camel-k/pkg/platform"
-	"github.com/apache/camel-k/pkg/util/digest"
-	"github.com/apache/camel-k/pkg/util/log"
-	"github.com/apache/camel-k/pkg/util/monitoring"
+	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
+	"github.com/apache/camel-k/v2/pkg/client"
+	camelevent "github.com/apache/camel-k/v2/pkg/event"
+	"github.com/apache/camel-k/v2/pkg/platform"
+	"github.com/apache/camel-k/v2/pkg/util/digest"
+	"github.com/apache/camel-k/v2/pkg/util/log"
+	"github.com/apache/camel-k/v2/pkg/util/monitoring"
 )
 
 // Add creates a new IntegrationKit Controller and adds it to the Manager. The Manager will set fields on the Controller
@@ -147,6 +148,11 @@ func add(_ context.Context, mgr manager.Manager, r reconcile.Reconciler) error {
 				}
 
 				for _, kit := range list.Items {
+					if v, ok := kit.Annotations[v1.PlatformSelectorAnnotation]; ok && v != p.Name {
+						log.Infof("Integration kit %s is waiting for selected integration platform '%s' - skip it now", kit.Name, v)
+						continue
+					}
+
 					if kit.Status.Phase == v1.IntegrationKitPhaseWaitingForPlatform {
 						log.Infof("Platform %s ready, wake-up integration kit: %s", p.Name, kit.Name)
 						requests = append(requests, reconcile.Request{
@@ -202,7 +208,7 @@ func (r *reconcileIntegrationKit) Reconcile(ctx context.Context, request reconci
 
 	// Fetch the IntegrationKit instance
 	if err := r.client.Get(ctx, request.NamespacedName, &instance); err != nil {
-		if errors.IsNotFound(err) {
+		if k8serrors.IsNotFound(err) {
 			// Request object not found, could have been deleted after reconcile request.
 			// Owned objects are automatically garbage collected. For additional cleanup logic use finalizers.
 			// Return and don't requeue
@@ -259,6 +265,8 @@ func (r *reconcileIntegrationKit) Reconcile(ctx context.Context, request reconci
 		NewErrorAction(),
 	}
 
+	targetPhase := instance.Status.Phase
+
 	for _, a := range actions {
 		a.InjectClient(r.client)
 		a.InjectLogger(targetLog)
@@ -267,6 +275,7 @@ func (r *reconcileIntegrationKit) Reconcile(ctx context.Context, request reconci
 			targetLog.Infof("Invoking action %s", a.Name())
 
 			newTarget, err := a.Handle(ctx, target)
+
 			if err != nil {
 				camelevent.NotifyIntegrationKitError(ctx, r.client, r.recorder, &instance, newTarget, err)
 				return reconcile.Result{}, err
@@ -278,11 +287,13 @@ func (r *reconcileIntegrationKit) Reconcile(ctx context.Context, request reconci
 					return res, err
 				}
 
-				if newTarget.Status.Phase != instance.Status.Phase {
+				targetPhase = newTarget.Status.Phase
+
+				if targetPhase != instance.Status.Phase {
 					targetLog.Info(
 						"state transition",
 						"phase-from", instance.Status.Phase,
-						"phase-to", newTarget.Status.Phase,
+						"phase-to", targetPhase,
 					)
 				}
 			}
@@ -294,6 +305,13 @@ func (r *reconcileIntegrationKit) Reconcile(ctx context.Context, request reconci
 		}
 	}
 
+	if targetPhase == v1.IntegrationKitPhaseWaitingForCatalog {
+		// Requeue
+		return reconcile.Result{
+			RequeueAfter: 2 * time.Second,
+		}, nil
+	}
+
 	return reconcile.Result{}, nil
 }
 
