@@ -20,8 +20,8 @@ package kamelet
 import (
 	"context"
 
-	"github.com/apache/camel-k/pkg/apis/camel/v1alpha1"
-	kameletutils "github.com/apache/camel-k/pkg/kamelet"
+	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
+	kameletutils "github.com/apache/camel-k/v2/pkg/kamelet"
 )
 
 // NewInitializeAction returns a action that initializes the kamelet configuration when not provided by the user.
@@ -37,10 +37,10 @@ func (action *initializeAction) Name() string {
 	return "initialize"
 }
 
-func (action *initializeAction) CanHandle(kamelet *v1alpha1.Kamelet) bool {
-	return kamelet.Status.Phase == v1alpha1.KameletPhaseNone
+func (action *initializeAction) CanHandle(kamelet *v1.Kamelet) bool {
+	return kamelet.Status.Phase == v1.KameletPhaseNone
 }
 
-func (action *initializeAction) Handle(ctx context.Context, kamelet *v1alpha1.Kamelet) (*v1alpha1.Kamelet, error) {
+func (action *initializeAction) Handle(ctx context.Context, kamelet *v1.Kamelet) (*v1.Kamelet, error) {
 	return kameletutils.Initialize(kamelet)
 }
