@@ -20,11 +20,11 @@ package install
 import (
 	"context"
 
-	v1 "github.com/apache/camel-k/pkg/apis/camel/v1"
-	"github.com/apache/camel-k/pkg/client"
+	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
+	"github.com/apache/camel-k/v2/pkg/client"
 )
 
-// BuilderServiceAccountRoles installs the builder service account and related roles in the given namespace
+// BuilderServiceAccountRoles installs the builder service account and related roles in the given namespace.
 func BuilderServiceAccountRoles(ctx context.Context, c client.Client, namespace string, cluster v1.IntegrationPlatformCluster) error {
 	if cluster == v1.IntegrationPlatformClusterOpenShift {
 		if err := installBuilderServiceAccountRolesOpenShift(ctx, c, namespace); err != nil {
