@@ -25,21 +25,20 @@ import (
 	appsv1 "k8s.io/api/apps/v1"
 	batchv1 "k8s.io/api/batch/v1"
 	corev1 "k8s.io/api/core/v1"
-	"k8s.io/apimachinery/pkg/api/resource"
 	"k8s.io/apimachinery/pkg/util/intstr"
 	"k8s.io/utils/pointer"
 
 	serving "knative.dev/serving/pkg/apis/serving/v1"
 
-	v1 "github.com/apache/camel-k/pkg/apis/camel/v1"
-	traitv1 "github.com/apache/camel-k/pkg/apis/camel/v1/trait"
-	"github.com/apache/camel-k/pkg/util"
-	"github.com/apache/camel-k/pkg/util/camel"
-	"github.com/apache/camel-k/pkg/util/defaults"
-	"github.com/apache/camel-k/pkg/util/digest"
-	"github.com/apache/camel-k/pkg/util/envvar"
-	"github.com/apache/camel-k/pkg/util/knative"
-	"github.com/apache/camel-k/pkg/util/kubernetes"
+	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
+	traitv1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1/trait"
+	"github.com/apache/camel-k/v2/pkg/util"
+	"github.com/apache/camel-k/v2/pkg/util/camel"
+	"github.com/apache/camel-k/v2/pkg/util/defaults"
+	"github.com/apache/camel-k/v2/pkg/util/digest"
+	"github.com/apache/camel-k/v2/pkg/util/envvar"
+	"github.com/apache/camel-k/v2/pkg/util/knative"
+	"github.com/apache/camel-k/v2/pkg/util/kubernetes"
 )
 
 const (
@@ -71,6 +70,7 @@ func (t *containerTrait) Configure(e *Environment) (bool, error) {
 	if e.Integration == nil || !pointer.BoolDeref(t.Enabled, true) {
 		return false, nil
 	}
+
 	if !e.IntegrationInPhase(v1.IntegrationPhaseInitialization) && !e.IntegrationInRunningPhases() {
 		return false, nil
 	}
@@ -194,7 +194,7 @@ func (t *containerTrait) configureContainer(e *Environment) error {
 		e.Resources.Add(props)
 	}
 
-	t.configureResources(e, &container)
+	t.configureResources(&container)
 	if pointer.BoolDeref(t.Expose, false) {
 		t.configureService(e, &container)
 	}
@@ -302,50 +302,36 @@ func (t *containerTrait) configureService(e *Environment, container *corev1.Cont
 	service.Labels["camel.apache.org/service.type"] = v1.ServiceTypeUser
 }
 
-func (t *containerTrait) configureResources(_ *Environment, container *corev1.Container) {
-	// Requests
-	if container.Resources.Requests == nil {
-		container.Resources.Requests = make(corev1.ResourceList)
+func (t *containerTrait) configureResources(container *corev1.Container) {
+	requestsList := container.Resources.Requests
+	limitsList := container.Resources.Limits
+	var err error
+	if requestsList == nil {
+		requestsList = make(corev1.ResourceList)
+	}
+	if limitsList == nil {
+		limitsList = make(corev1.ResourceList)
 	}
 
-	if t.RequestCPU != "" {
-		v, err := resource.ParseQuantity(t.RequestCPU)
-		if err != nil {
-			t.L.Error(err, "unable to parse quantity", "request-cpu", t.RequestCPU)
-		} else {
-			container.Resources.Requests[corev1.ResourceCPU] = v
-		}
+	requestsList, err = kubernetes.ConfigureResource(t.RequestCPU, requestsList, corev1.ResourceCPU)
+	if err != nil {
+		t.L.Error(err, "unable to parse quantity", "request-cpu", t.RequestCPU)
 	}
-	if t.RequestMemory != "" {
-		v, err := resource.ParseQuantity(t.RequestMemory)
-		if err != nil {
-			t.L.Error(err, "unable to parse quantity", "request-memory", t.RequestMemory)
-		} else {
-			container.Resources.Requests[corev1.ResourceMemory] = v
-		}
+	requestsList, err = kubernetes.ConfigureResource(t.RequestMemory, requestsList, corev1.ResourceMemory)
+	if err != nil {
+		t.L.Error(err, "unable to parse quantity", "request-memory", t.RequestMemory)
+	}
+	limitsList, err = kubernetes.ConfigureResource(t.LimitCPU, limitsList, corev1.ResourceCPU)
+	if err != nil {
+		t.L.Error(err, "unable to parse quantity", "limit-cpu", t.LimitCPU)
+	}
+	limitsList, err = kubernetes.ConfigureResource(t.LimitMemory, limitsList, corev1.ResourceMemory)
+	if err != nil {
+		t.L.Error(err, "unable to parse quantity", "limit-memory", t.LimitMemory)
 	}
 
-	// Limits
-	if container.Resources.Limits == nil {
-		container.Resources.Limits = make(corev1.ResourceList)
-	}
-
-	if t.LimitCPU != "" {
-		v, err := resource.ParseQuantity(t.LimitCPU)
-		if err != nil {
-			t.L.Error(err, "unable to parse quantity", "limit-cpu", t.LimitCPU)
-		} else {
-			container.Resources.Limits[corev1.ResourceCPU] = v
-		}
-	}
-	if t.LimitMemory != "" {
-		v, err := resource.ParseQuantity(t.LimitMemory)
-		if err != nil {
-			t.L.Error(err, "unable to parse quantity", "limit-memory", t.LimitMemory)
-		} else {
-			container.Resources.Limits[corev1.ResourceMemory] = v
-		}
-	}
+	container.Resources.Requests = requestsList
+	container.Resources.Limits = limitsList
 }
 
 func (t *containerTrait) configureCapabilities(e *Environment) {
