@@ -20,9 +20,9 @@ package trait
 import (
 	"testing"
 
-	"github.com/apache/camel-k/pkg/util/camel"
+	"github.com/apache/camel-k/v2/pkg/util/camel"
 
-	v1 "github.com/apache/camel-k/pkg/apis/camel/v1"
+	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
 
 	"github.com/stretchr/testify/assert"
 )
