@@ -27,12 +27,12 @@ import (
 	corev1 "k8s.io/api/core/v1"
 	"k8s.io/utils/pointer"
 
-	v1 "github.com/apache/camel-k/pkg/apis/camel/v1"
-	traitv1 "github.com/apache/camel-k/pkg/apis/camel/v1/trait"
-	"github.com/apache/camel-k/pkg/builder"
-	"github.com/apache/camel-k/pkg/util/defaults"
-	"github.com/apache/camel-k/pkg/util/kubernetes"
-	"github.com/apache/camel-k/pkg/util/log"
+	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
+	traitv1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1/trait"
+	"github.com/apache/camel-k/v2/pkg/builder"
+	"github.com/apache/camel-k/v2/pkg/util/defaults"
+	"github.com/apache/camel-k/v2/pkg/util/kubernetes"
+	"github.com/apache/camel-k/v2/pkg/util/log"
 )
 
 const (
@@ -106,6 +106,11 @@ func (t *quarkusTrait) InfluencesKit() bool {
 	return true
 }
 
+// InfluencesBuild overrides base class method.
+func (t *quarkusTrait) InfluencesBuild(this, prev map[string]interface{}) bool {
+	return true
+}
+
 var _ ComparableTrait = &quarkusTrait{}
 
 func (t *quarkusTrait) Matches(trait Trait) bool {
@@ -285,7 +290,7 @@ func propagateKitTraits(e *Environment) v1.IntegrationKitTraits {
 }
 
 func (t *quarkusTrait) applyWhenBuildSubmitted(e *Environment) error {
-	build := getBuilderTask(e.BuildTasks)
+	build := getBuilderTask(e.Pipeline)
 	if build == nil {
 		return fmt.Errorf("unable to find builder task: %s", e.Integration.Name)
 	}
