@@ -18,16 +18,14 @@ limitations under the License.
 package trait
 
 import (
-	"reflect"
+	"errors"
+	"fmt"
 	"sort"
 	"strings"
 
-	"github.com/fatih/structs"
-	"github.com/pkg/errors"
-
-	v1 "github.com/apache/camel-k/pkg/apis/camel/v1"
-	"github.com/apache/camel-k/pkg/client"
-	"github.com/apache/camel-k/pkg/util/log"
+	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
+	"github.com/apache/camel-k/v2/pkg/client"
+	"github.com/apache/camel-k/v2/pkg/util/log"
 )
 
 // Catalog collects all information about traits in one place.
@@ -119,7 +117,7 @@ func (c *Catalog) apply(environment *Environment) error {
 			for _, processor := range environment.PostStepProcessors {
 				err := processor(environment)
 				if err != nil {
-					return errors.Wrap(err, "error executing post step action")
+					return fmt.Errorf("error executing post step action: %w", err)
 				}
 			}
 		}
@@ -138,7 +136,7 @@ func (c *Catalog) apply(environment *Environment) error {
 	for _, processor := range environment.PostProcessors {
 		err := processor(environment)
 		if err != nil {
-			return errors.Wrap(err, "error executing post processor")
+			return fmt.Errorf("error executing post processor: %w", err)
 		}
 	}
 
@@ -155,42 +153,6 @@ func (c *Catalog) GetTrait(id string) Trait {
 	return nil
 }
 
-// ComputeTraitsProperties returns all key/value configuration properties that can be used to configure traits.
-func (c *Catalog) ComputeTraitsProperties() []string {
-	results := make([]string, 0)
-	for _, trait := range c.AllTraits() {
-		trait := trait // pin
-		c.processFields(structs.Fields(trait), func(name string) {
-			results = append(results, string(trait.ID())+"."+name)
-		})
-	}
-
-	return results
-}
-
-func (c *Catalog) processFields(fields []*structs.Field, processor func(string)) {
-	for _, f := range fields {
-		if f.IsEmbedded() && f.IsExported() && f.Kind() == reflect.Struct {
-			c.processFields(f.Fields(), processor)
-		}
-
-		if f.IsEmbedded() {
-			continue
-		}
-
-		property := f.Tag("property")
-
-		if property != "" {
-			items := strings.Split(property, ",")
-			if f.Kind() == reflect.Map {
-				processor(items[0] + ".*")
-			} else {
-				processor(items[0])
-			}
-		}
-	}
-}
-
 type Finder interface {
 	GetTrait(id string) Trait
 }
