@@ -23,9 +23,9 @@ import (
 	"path/filepath"
 	"strings"
 
-	v1 "github.com/apache/camel-k/pkg/apis/camel/v1"
-	"github.com/apache/camel-k/pkg/util/jitpack"
-	"github.com/apache/camel-k/pkg/util/maven"
+	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
+	"github.com/apache/camel-k/v2/pkg/util/jitpack"
+	"github.com/apache/camel-k/v2/pkg/util/maven"
 	"github.com/rs/xid"
 )
 
@@ -49,15 +49,6 @@ func NormalizeDependency(dependency string) string {
 	return newDep
 }
 
-// ValidateDependencies validates dependencies against Camel catalog.
-// It only shows warning and does not throw error in case the Catalog is just not complete
-// and we don't want to let it stop the process.
-func ValidateDependencies(catalog *RuntimeCatalog, dependencies []string, out io.Writer) {
-	for _, d := range dependencies {
-		ValidateDependency(catalog, d, out)
-	}
-}
-
 // ValidateDependency validates a dependency against Camel catalog.
 // It only shows warning and does not throw error in case the Catalog is just not complete,
 // and we don't want to let it stop the process.
