@@ -20,8 +20,8 @@ package log
 import (
 	"fmt"
 
-	v1 "github.com/apache/camel-k/pkg/apis/camel/v1"
-	"github.com/apache/camel-k/pkg/apis/camel/v1alpha1"
+	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
+	"github.com/apache/camel-k/v2/pkg/apis/camel/v1alpha1"
 	"github.com/go-logr/logr"
 	logf "sigs.k8s.io/controller-runtime/pkg/log"
 )
@@ -130,7 +130,17 @@ func (l Logger) ForIntegrationPlatform(target *v1.IntegrationPlatform) Logger {
 }
 
 // ForKamelet --.
-func (l Logger) ForKamelet(target *v1alpha1.Kamelet) Logger {
+func (l Logger) ForKamelet(target *v1.Kamelet) Logger {
+	return l.WithValues(
+		"api-version", target.APIVersion,
+		"kind", target.Kind,
+		"ns", target.Namespace,
+		"name", target.Name,
+	)
+}
+
+// ForPipe --.
+func (l Logger) ForPipe(target *v1.Pipe) Logger {
 	return l.WithValues(
 		"api-version", target.APIVersion,
 		"kind", target.Kind,
@@ -140,6 +150,7 @@ func (l Logger) ForKamelet(target *v1alpha1.Kamelet) Logger {
 }
 
 // ForKameletBinding --.
+// Deprecated: use ForPipe instead.
 func (l Logger) ForKameletBinding(target *v1alpha1.KameletBinding) Logger {
 	return l.WithValues(
 		"api-version", target.APIVersion,
@@ -149,6 +160,21 @@ func (l Logger) ForKameletBinding(target *v1alpha1.KameletBinding) Logger {
 	)
 }
 
+// ForCatalog --.
+func (l Logger) ForCatalog(target *v1.CamelCatalog) Logger {
+	return l.WithValues(
+		"api-version", target.APIVersion,
+		"kind", target.Kind,
+		"ns", target.Namespace,
+		"name", target.Name,
+	)
+}
+
+// AsLogger --.
+func (l Logger) AsLogger() logr.Logger {
+	return l.delegate
+}
+
 // ***********************************
 //
 // Helpers
