@@ -28,7 +28,7 @@ import (
 	operatorsv1alpha1 "github.com/operator-framework/api/pkg/operators/v1alpha1"
 	operatorsv1alpha2 "github.com/operator-framework/api/pkg/operators/v1alpha2"
 
-	kubernetesutils "github.com/apache/camel-k/pkg/util/kubernetes"
+	kubernetesutils "github.com/apache/camel-k/v2/pkg/util/kubernetes"
 )
 
 // IsAPIAvailable returns true if we are connected to a cluster with OLM installed.
