@@ -25,9 +25,9 @@ import (
 	"regexp"
 	"strings"
 
-	"github.com/apache/camel-k/pkg/client"
-	"github.com/apache/camel-k/pkg/util/camel"
-	"github.com/apache/camel-k/pkg/util/kubernetes"
+	"github.com/apache/camel-k/v2/pkg/client"
+	"github.com/apache/camel-k/v2/pkg/util/camel"
+	"github.com/apache/camel-k/v2/pkg/util/kubernetes"
 	corev1 "k8s.io/api/core/v1"
 	k8serrors "k8s.io/apimachinery/pkg/api/errors"
 )
@@ -87,8 +87,6 @@ const (
 	StorageTypeConfigmap StorageType = "configmap"
 	// StorageTypeSecret --.
 	StorageTypeSecret StorageType = "secret"
-	// StorageTypeFile --.
-	StorageTypeFile StorageType = "file"
 	// StorageTypePVC --.
 	StorageTypePVC StorageType = "pvc"
 )
@@ -105,12 +103,11 @@ const (
 
 var (
 	validConfigSecretRegexp = regexp.MustCompile(`^(configmap|secret)\:([\w\.\-\_\:\/@]+)$`)
-	validFileRegexp         = regexp.MustCompile(`^file\:([\w\.\-\_\:\/@" ]+)$`)
 	validResourceRegexp     = regexp.MustCompile(`^([\w\.\-\_\:]+)(\/([\w\.\-\_\:]+))?(\@([\w\.\-\_\:\/]+))?$`)
 )
 
 func newConfig(storageType StorageType, contentType ContentType, value string) *Config {
-	rn, mk, mp := parseResourceValue(storageType, value)
+	rn, mk, mp := parseCMOrSecretValue(value)
 	return &Config{
 		storageType:     storageType,
 		contentType:     contentType,
@@ -120,15 +117,6 @@ func newConfig(storageType StorageType, contentType ContentType, value string) *
 	}
 }
 
-func parseResourceValue(storageType StorageType, value string) (string, string, string) {
-	if storageType == StorageTypeFile {
-		resource, maybeDestinationPath := ParseFileValue(value)
-		return resource, "", maybeDestinationPath
-	}
-
-	return parseCMOrSecretValue(value)
-}
-
 // ParseFileValue will parse a file resource/config option to return the local path and the
 // destination path expected.
 func ParseFileValue(value string) (string, string) {
@@ -189,13 +177,8 @@ func parse(item string, contentType ContentType) (*Config, error) {
 			cot = StorageTypeSecret
 		}
 		value = groups[2]
-	case validFileRegexp.MatchString(item):
-		// parse as file
-		groups := validFileRegexp.FindStringSubmatch(item)
-		cot = StorageTypeFile
-		value = groups[1]
 	default:
-		return nil, fmt.Errorf("could not match config, secret or file configuration as %s", item)
+		return nil, fmt.Errorf("could not match config or secret configuration as %s", item)
 	}
 
 	return newConfig(cot, contentType, value), nil
